@@ -1,40 +1,24 @@
 /*
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_AGENDAITEM_H
-#define EVENTVIEWS_AGENDAITEM_H
+#pragma once
 
 #include "viewcalendar.h"
 
 #include <CalendarSupport/CellItem>
 
 #include <Akonadi/Calendar/ETMCalendar>
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <QDateTime>
-#include <QWidget>
 #include <QPointer>
+#include <QWidget>
 
-namespace EventViews {
+namespace EventViews
+{
 class AgendaItem;
 class EventView;
 
@@ -78,10 +62,16 @@ class AgendaItem : public QWidget, public CalendarSupport::CellItem
 {
     Q_OBJECT
 public:
-    typedef QPointer<AgendaItem> QPtr;
-    typedef QList<QPtr> List;
+    using QPtr = QPointer<AgendaItem>;
+    using List = QList<QPtr>;
 
-    AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence, int itemPos, int itemCount, const QDateTime &qd, bool isSelected,
+    AgendaItem(EventView *eventView,
+               const MultiViewCalendar::Ptr &calendar,
+               const KCalendarCore::Incidence::Ptr &incidence,
+               int itemPos,
+               int itemCount,
+               const QDateTime &qd,
+               bool isSelected,
                QWidget *parent);
     ~AgendaItem() override;
 
@@ -268,7 +258,7 @@ protected:
 
     // Variables to remember start position
     MultiItemInfo *mStartMoveInfo = nullptr;
-    //Color of the resource
+    // Color of the resource
     QColor mResourceColor;
 
 private:
@@ -277,7 +267,7 @@ private:
     // paint all visible icons
     void paintIcons(QPainter *p, int &x, int y, int ft);
 
-    void drawRoundedRect(QPainter *p, const QRect &rect, bool selected, const QColor &bgcolor, bool frame, int ft, bool roundTop, bool roundBottom);
+    void drawRoundedRect(QPainter *p, QRect rect, bool selected, const QColor &bgColor, const QColor &frameColor, bool frame, int ft, bool roundTop, bool roundBottom);
 
     Q_REQUIRED_RESULT QColor getCategoryColor() const;
     Q_REQUIRED_RESULT QColor getFrameColor(const QColor &resourceColor, const QColor &categoryColor) const;
@@ -286,17 +276,22 @@ private:
     int mCellXLeft, mCellXRight;
     int mCellYTop, mCellYBottom;
 
-    EventView *mEventView = nullptr;
+    EventView *const mEventView;
     MultiViewCalendar::Ptr mCalendar;
     KCalendarCore::Incidence::Ptr mIncidence;
     QDateTime mOccurrenceDateTime;
-    bool mValid;
-    bool mCloned;
+    bool mValid = true;
+    bool mCloned = false;
     QString mLabelText;
     bool mSelected;
-    bool mIconAlarm, mIconRecur, mIconReadonly;
-    bool mIconReply, mIconGroup, mIconGroupTent;
-    bool mIconOrganizer, mSpecialEvent;
+    bool mIconAlarm;
+    bool mIconRecur;
+    bool mIconReadonly;
+    bool mIconReply;
+    bool mIconGroup;
+    bool mIconGroupTent;
+    bool mIconOrganizer;
+    bool mSpecialEvent;
 
     // For incidences that expand through more than 1 day
     // Will be 1 for single day incidences
@@ -321,4 +316,3 @@ private:
 };
 }
 
-#endif
