@@ -1,45 +1,29 @@
 /*
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2007 Bruno Virlet <bruno@virlet.org>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Bruno Virlet <bruno@virlet.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_TIMELABELS_H
-#define EVENTVIEWS_TIMELABELS_H
+#pragma once
 
 #include <QTimeZone>
 
 #include <QFrame>
 
-namespace EventViews {
+namespace EventViews
+{
 class Agenda;
 class TimeLabelsZone;
 
 class Prefs;
-typedef QSharedPointer<Prefs> PrefsPtr;
+using PrefsPtr = QSharedPointer<Prefs>;
 
-class TimeLabels : public QFrame
+class TimeLabels : public QWidget
 {
     Q_OBJECT
 public:
-    typedef QList<TimeLabels *> List;
+    using List = QList<TimeLabels *>;
 
     TimeLabels(const QTimeZone &zone, int rows, TimeLabelsZone *parent = nullptr, Qt::WindowFlags f = {});
 
@@ -81,22 +65,21 @@ private:
     Q_REQUIRED_RESULT QString cellToSuffix(const int cell) const;
 
     /** update the position of the marker showing the mouse position */
-    void mousePosChanged(const QPoint &pos);
+    void mousePosChanged(QPoint pos);
 
     void showMousePos();
     void hideMousePos();
 
     void setCellHeight(double height);
     void colorMousePos();
-    QTimeZone mTimezone;
+    const QTimeZone mTimezone;
     int mRows;
     double mCellHeight;
     int mMiniWidth;
     Agenda *mAgenda = nullptr;
     TimeLabelsZone *mTimeLabelsZone = nullptr;
 
-    QFrame *mMousePos = nullptr;  // shows a marker for the current mouse position in y direction
+    QFrame *mMousePos = nullptr; // shows a marker for the current mouse position in y direction
 };
 }
 
-#endif
