@@ -6,8 +6,8 @@
 
 #include "viewcalendar.h"
 #include "agendaview.h"
-#include "helper.h"
 #include "calendarview_debug.h"
+#include "helper.h"
 
 #include <CalendarSupport/Utils>
 
@@ -29,7 +29,7 @@ KCalendarCore::Calendar::Ptr MultiViewCalendar::getCalendar() const
 KCalendarCore::Incidence::List MultiViewCalendar::incidences() const
 {
     KCalendarCore::Incidence::List list;
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->getCalendar()) {
             list += cal->getCalendar()->incidences();
         }
@@ -44,7 +44,7 @@ int MultiViewCalendar::calendars() const
 
 ViewCalendar::Ptr MultiViewCalendar::findCalendar(const KCalendarCore::Incidence::Ptr &incidence) const
 {
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->isValid(incidence)) {
             return cal;
         }
@@ -54,7 +54,7 @@ ViewCalendar::Ptr MultiViewCalendar::findCalendar(const KCalendarCore::Incidence
 
 ViewCalendar::Ptr MultiViewCalendar::findCalendar(const QString &incidenceIdentifier) const
 {
-    for (const ViewCalendar::Ptr &cal : qAsConst(mSubCalendars)) {
+    for (const ViewCalendar::Ptr &cal : std::as_const(mSubCalendars)) {
         if (cal->isValid(incidenceIdentifier)) {
             return cal;
         }
@@ -115,7 +115,7 @@ QColor MultiViewCalendar::resourceColor(const KCalendarCore::Incidence::Ptr &inc
     if (cal) {
         return cal->resourceColor(incidence);
     }
-    return QColor();
+    return {};
 }
 
 Akonadi::Item MultiViewCalendar::item(const KCalendarCore::Incidence::Ptr &incidence) const
@@ -165,8 +165,7 @@ Akonadi::Item AkonadiViewCalendar::item(const KCalendarCore::Incidence::Ptr &inc
 
         if (id == -1) {
             // Ok, we really don't know the ID, give up.
-            qCWarning(CALENDARVIEW_LOG) << "Item is invalid. uid = "
-                                        << incidence->instanceIdentifier();
+            qCWarning(CALENDARVIEW_LOG) << "Item is invalid. uid = " << incidence->instanceIdentifier();
             return Akonadi::Item();
         }
         return mCalendar->item(incidence->instanceIdentifier());
