@@ -1,27 +1,11 @@
 /*
   This file is part of KOrganizer.
 
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2007 Mike McQuaid <mike@mikemcquaid.com>
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2007 Mike McQuaid <mike@mikemcquaid.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 // Journal Entry
@@ -33,21 +17,20 @@
 #include <KCalendarCore/Journal>
 
 #include <KCalUtils/IncidenceFormatter>
-#include <Akonadi/Calendar/ETMCalendar>
 
-#include <QTextBrowser>
-#include <KLocalizedString>
 #include "calendarview_debug.h"
+#include <KLocalizedString>
+#include <QTextBrowser>
 
 #include <QEvent>
+#include <QFontDatabase>
 #include <QHBoxLayout>
 #include <QPushButton>
-#include <QFontDatabase>
 
 using namespace EventViews;
 
 JournalDateView::JournalDateView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent)
-    : QFrame(parent)
+    : QWidget(parent)
     , mCalendar(calendar)
 {
     auto layout = new QVBoxLayout(this);
@@ -59,7 +42,7 @@ JournalDateView::~JournalDateView()
 {
 }
 
-void JournalDateView::setDate(const QDate &date)
+void JournalDateView::setDate(QDate date)
 {
     mDate = date;
     Q_EMIT setDateSignal(date);
@@ -79,11 +62,11 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
         return;
     }
 
-    QWidget *container = new QWidget(this);
+    auto container = new QWidget(this);
     layout()->addWidget(container);
-    QHBoxLayout *layout = new QHBoxLayout(container);
+    auto layout = new QHBoxLayout(container);
     layout->addStretch(1);
-    JournalFrame *entry = new JournalFrame(j, mCalendar, this);
+    auto entry = new JournalFrame(j, mCalendar, this);
     layout->addWidget(entry, 3 /*stretch*/);
     layout->addStretch(1);
 
@@ -92,25 +75,22 @@ void JournalDateView::addJournal(const Akonadi::Item &j)
     entry->setIncidenceChanger(mChanger);
 
     mEntries.insert(j.id(), entry);
-    connect(this, &JournalDateView::setIncidenceChangerSignal,
-            entry, &JournalFrame::setIncidenceChanger);
-    connect(this, &JournalDateView::setDateSignal,
-            entry, &JournalFrame::setDate);
-    connect(entry, &JournalFrame::deleteIncidence,
-            this, &JournalDateView::deleteIncidence);
-    connect(entry, &JournalFrame::editIncidence,
-            this, &JournalDateView::editIncidence);
-    connect(entry, &JournalFrame::incidenceSelected,
-            this, &JournalDateView::incidenceSelected);
-    connect(entry, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalFrame::printJournal),
-            this, QOverload<const KCalendarCore::Journal::Ptr &, bool>::of(&JournalDateView::printJournal));
+    connect(this, &JournalDateView::setIncidenceChangerSignal, entry, &JournalFrame::setIncidenceChanger);
+    connect(this, &JournalDateView::setDateSignal, entry, &JournalFrame::setDate);
+    connect(entry, &JournalFrame::deleteIncidence, this, &JournalDateView::deleteIncidence);
+    connect(entry, &JournalFrame::editIncidence, this, &JournalDateView::editIncidence);
+    connect(entry, &JournalFrame::incidenceSelected, this, &JournalDateView::incidenceSelected);
+    connect(entry,
+            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalFrame::printJournal),
+            this,
+            qOverload<const KCalendarCore::Journal::Ptr &, bool>(&JournalDateView::printJournal));
 }
 
 Akonadi::Item::List JournalDateView::journals() const
 {
     Akonadi::Item::List l;
     l.reserve(mEntries.count());
-    for (const JournalFrame *const i : qAsConst(mEntries)) {
+    for (const JournalFrame *const i : std::as_const(mEntries)) {
         l.push_back(i->journal());
     }
     return l;
@@ -157,14 +137,14 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mWriteInProgress = false;
     mChanger = nullptr;
 
-    QVBoxLayout *verticalLayout = new QVBoxLayout(this);
+    auto verticalLayout = new QVBoxLayout(this);
 
     mBrowser = new QTextBrowser(this);
     mBrowser->viewport()->installEventFilter(this);
     mBrowser->setFrameStyle(QFrame::NoFrame);
     verticalLayout->addWidget(mBrowser);
 
-    QHBoxLayout *buttonsLayout = new QHBoxLayout();
+    auto buttonsLayout = new QHBoxLayout();
     verticalLayout->addLayout(buttonsLayout);
     buttonsLayout->addStretch();
 
@@ -196,7 +176,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mPrintButton->setToolTip(i18n("Print this journal entry"));
     mPrintButton->setWhatsThis(i18n("Opens a print dialog for this journal entry"));
     buttonsLayout->addWidget(mPrintButton);
-    connect(mPrintButton, &QPushButton::clicked, this, QOverload<>::of(&JournalFrame::printJournal));
+    connect(mPrintButton, &QPushButton::clicked, this, qOverload<>(&JournalFrame::printJournal));
 
     mPrintPreviewButton = new QPushButton(this);
     mPrintPreviewButton->setText(i18n("Print preview"));
@@ -205,8 +185,7 @@ JournalFrame::JournalFrame(const Akonadi::Item &j, const Akonadi::ETMCalendar::P
     mPrintPreviewButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     mPrintPreviewButton->setToolTip(i18n("Print preview this journal entry"));
     buttonsLayout->addWidget(mPrintPreviewButton);
-    connect(mPrintPreviewButton, &QAbstractButton::clicked, this,
-            &JournalFrame::printPreviewJournal);
+    connect(mPrintPreviewButton, &QAbstractButton::clicked, this, &JournalFrame::printPreviewJournal);
 
     readJournal(mJournal);
     mDirty = false;
@@ -222,7 +201,7 @@ JournalFrame::~JournalFrame()
 
 bool JournalFrame::eventFilter(QObject *object, QEvent *event)
 {
-    Q_UNUSED(object);
+    Q_UNUSED(object)
 
     // object is our QTextBrowser
     if (!mJournal.isValid()) {
@@ -262,7 +241,7 @@ void JournalFrame::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
     mCalendar = calendar;
 }
 
-void JournalFrame::setDate(const QDate &date)
+void JournalFrame::setDate(QDate date)
 {
     mDate = date;
 }
@@ -305,7 +284,7 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
     cursor.movePosition(QTextCursor::Start);
 
     QTextBlockFormat bodyBlock = QTextBlockFormat(cursor.blockFormat());
-    //FIXME: Do padding
+    // FIXME: Do padding
     bodyBlock.setTextIndent(2);
     QTextCharFormat bodyFormat = QTextCharFormat(cursor.charFormat());
     if (!journal->summary().isEmpty()) {
@@ -318,8 +297,7 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
     QTextCharFormat dateFormat = bodyFormat;
     dateFormat.setFontWeight(QFont::Bold);
     dateFormat.setFontPointSize(baseFontSize + 1);
-    cursor.insertText(KCalUtils::IncidenceFormatter::dateTimeToString(
-                          journal->dtStart(), journal->allDay()), dateFormat);
+    cursor.insertText(KCalUtils::IncidenceFormatter::dateTimeToString(journal->dtStart(), journal->allDay()), dateFormat);
     cursor.insertBlock();
     cursor.insertBlock();
     cursor.setBlockCharFormat(bodyFormat);
@@ -329,6 +307,9 @@ void JournalFrame::readJournal(const Akonadi::Item &j)
     } else {
         mBrowser->insertPlainText(description);
     }
+    cursor.movePosition(QTextCursor::Start);
+    mBrowser->setTextCursor(cursor);
+    mBrowser->ensureCursorVisible();
 
     if (mCalendar) {
         mEditButton->setEnabled(mCalendar->hasRight(j, Akonadi::Collection::CanChangeItem));
