@@ -1,30 +1,14 @@
 /*
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2010 Sérgio Martins <iamsergio@gmail.com>
-  Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-//TODO: put a reminder and/or recurs icon on the item?
+// TODO: put a reminder and/or recurs icon on the item?
 
 #include "listview.h"
 #include "helper.h"
@@ -44,8 +28,8 @@
 #include <QBoxLayout>
 #include <QHeaderView>
 #include <QIcon>
-#include <QTreeWidget>
 #include <QLocale>
+#include <QTreeWidget>
 
 using namespace EventViews;
 using namespace KCalendarCore;
@@ -59,8 +43,8 @@ enum {
     Dummy_EOF_Column // Dummy enum value for iteration purposes only. Always keep at the end.
 };
 
-static const QTime DAY_START {00, 00};
-static const QTime DAY_END   {23, 59, 59, 999};
+static const QTime DAY_START{00, 00};
+static const QTime DAY_END{23, 59, 59, 999};
 
 static QString cleanSummary(const QString &summary, const QDateTime &next)
 {
@@ -69,8 +53,7 @@ static QString cleanSummary(const QString &summary, const QDateTime &next)
 
     if (next.isValid()) {
         const QString dateStr = QLocale().toString(next.date(), QLocale::ShortFormat);
-        retStr = i18nc("%1 is an item summary. %2 is the date when this item reoccurs",
-                       "%1 (next: %2)", retStr, dateStr);
+        retStr = i18nc("%1 is an item summary. %2 is the date when this item reoccurs", "%1 (next: %2)", retStr, dateStr);
     }
     return retStr;
 }
@@ -87,7 +70,7 @@ public:
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
-    const QTreeWidget *mTreeWidget = nullptr;
+    QTreeWidget *const mTreeWidget;
     const Akonadi::Item mIncidence;
     QDateTime start;
     QDateTime end;
@@ -95,7 +78,7 @@ public:
 
 bool ListViewItem::operator<(const QTreeWidgetItem &other) const
 {
-    const ListViewItem *otheritem = static_cast<const ListViewItem *>(&other);
+    const auto otheritem = static_cast<const ListViewItem *>(&other);
 
     switch (treeWidget()->sortColumn()) {
     case StartDateTime_Column:
@@ -105,24 +88,24 @@ bool ListViewItem::operator<(const QTreeWidgetItem &other) const
         // Missing end times are sorted after any defined time.
         return end.isValid() && (!otheritem->end.isValid() || end < otheritem->end);
     default:
-        return QTreeWidgetItem::operator <(other);
+        return QTreeWidgetItem::operator<(other);
     }
 }
 
-class Q_DECL_HIDDEN ListView::Private
+class EventViews::ListViewPrivate
 {
 public:
-    Private()
+    ListViewPrivate()
     {
     }
 
-    ~Private()
+    ~ListViewPrivate()
     {
     }
 
-    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, const QDate &date);
-    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, const QDate &date);
-    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &, const QDate &date);
+    void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, QDate date);
+    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, QDate date);
+    void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &, QDate date);
     ListViewItem *getItemForIncidence(const Akonadi::Item &);
 
     QTreeWidget *mTreeWidget = nullptr;
@@ -132,6 +115,8 @@ public:
     QDate mStartDate;
     QDate mEndDate;
     DateList mSelectedDates;
+    int mSortColumn = StartDateTime_Column;
+    Qt::SortOrder mSortOrder = Qt::AscendingOrder;
 
     // if it's non interactive we disable context menu, and incidence editing
     bool mIsNonInteractive;
@@ -142,10 +127,11 @@ public:
   This class provides the initialization of a ListViewItem for calendar
   components using the Incidence::Visitor.
 */
-class ListView::Private::ListItemVisitor : public KCalendarCore::Visitor
+class ListViewPrivate::ListItemVisitor : public KCalendarCore::Visitor
 {
 public:
-    ListItemVisitor(ListViewItem *item, QDate dt) : mItem(item)
+    ListItemVisitor(ListViewItem *item, QDate dt)
+        : mItem(item)
         , mStartDate(dt)
     {
     }
@@ -168,7 +154,7 @@ private:
     QDate mStartDate;
 };
 
-bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
+bool ListViewPrivate::ListItemVisitor::visit(const Event::Ptr &e)
 {
     QIcon eventPxmp;
     if (e->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
@@ -198,13 +184,10 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     if (e->allDay()) {
         mItem->start.setTime(DAY_START);
         mItem->end.setTime(DAY_END);
-        mItem->setText(StartDateTime_Column,
-                       QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
-        mItem->setText(EndDateTime_Column,
-                       QLocale().toString(mItem->end.date(), QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column, QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
+        mItem->setText(EndDateTime_Column, QLocale().toString(mItem->end.date(), QLocale::ShortFormat));
     } else {
-        mItem->setText(StartDateTime_Column,
-                       QLocale().toString(mItem->start, QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column, QLocale().toString(mItem->start, QLocale::ShortFormat));
         mItem->setText(EndDateTime_Column, QLocale().toString(mItem->end, QLocale::ShortFormat));
     }
 
@@ -213,7 +196,7 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     return true;
 }
 
-bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
+bool ListViewPrivate::ListItemVisitor::visit(const Todo::Ptr &t)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(t->iconName()));
 
@@ -240,12 +223,9 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 
     if (t->hasStartDate()) {
         if (t->allDay()) {
-            mItem->setText(StartDateTime_Column,
-                           QLocale().toString(t->dtStart().toLocalTime().date(),
-                                              QLocale::ShortFormat));
+            mItem->setText(StartDateTime_Column, QLocale().toString(t->dtStart().toLocalTime().date(), QLocale::ShortFormat));
         } else {
-            mItem->setText(StartDateTime_Column,
-                           QLocale().toString(t->dtStart().toLocalTime(), QLocale::ShortFormat));
+            mItem->setText(StartDateTime_Column, QLocale().toString(t->dtStart().toLocalTime(), QLocale::ShortFormat));
         }
     } else {
         mItem->setText(StartDateTime_Column, QStringLiteral("---"));
@@ -253,12 +233,9 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 
     if (t->hasDueDate()) {
         if (t->allDay()) {
-            mItem->setText(EndDateTime_Column,
-                           QLocale().toString(t->dtDue().toLocalTime().date(),
-                                              QLocale::ShortFormat));
+            mItem->setText(EndDateTime_Column, QLocale().toString(t->dtDue().toLocalTime().date(), QLocale::ShortFormat));
         } else {
-            mItem->setText(EndDateTime_Column,
-                           QLocale().toString(t->dtDue().toLocalTime(), QLocale::ShortFormat));
+            mItem->setText(EndDateTime_Column, QLocale().toString(t->dtDue().toLocalTime(), QLocale::ShortFormat));
         }
     } else {
         mItem->setText(EndDateTime_Column, QStringLiteral("---"));
@@ -268,7 +245,7 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
     return true;
 }
 
-bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
+bool ListViewPrivate::ListItemVisitor::visit(const Journal::Ptr &j)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(j->iconName()));
 
@@ -276,19 +253,15 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
     mItem->end = QDateTime();
 
     if (j->summary().isEmpty()) {
-        mItem->setText(Summary_Column,
-                       cleanSummary(j->description().section(QLatin1Char('\n'), 0, 0),
-                                    QDateTime()));
+        mItem->setText(Summary_Column, cleanSummary(j->description().section(QLatin1Char('\n'), 0, 0), QDateTime()));
     } else {
         mItem->setText(Summary_Column, cleanSummary(j->summary(), QDateTime()));
     }
     if (j->allDay()) {
         mItem->start.setTime(DAY_START);
-        mItem->setText(StartDateTime_Column,
-                       QLocale().toString(j->dtStart().toLocalTime().date(), QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column, QLocale().toString(j->dtStart().toLocalTime().date(), QLocale::ShortFormat));
     } else {
-        mItem->setText(StartDateTime_Column,
-                       QLocale().toString(j->dtStart().toLocalTime(), QLocale::ShortFormat));
+        mItem->setText(StartDateTime_Column, QLocale().toString(j->dtStart().toLocalTime(), QLocale::ShortFormat));
     }
     mItem->setText(EndDateTime_Column, QStringLiteral("---"));
     mItem->setText(Categories_Column, j->categoriesStr());
@@ -298,7 +271,7 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
 
 ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, bool nonInteractive)
     : EventView(parent)
-    , d(new Private())
+    , d(new ListViewPrivate())
 {
     setCalendar(calendar);
     d->mActiveItem = nullptr;
@@ -310,7 +283,7 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, b
     d->mTreeWidget->headerItem()->setText(Summary_Column, i18n("Summary"));
     d->mTreeWidget->headerItem()->setText(StartDateTime_Column, i18n("Start Date/Time"));
     d->mTreeWidget->headerItem()->setText(EndDateTime_Column, i18n("End Date/Time"));
-    d->mTreeWidget->headerItem()->setText(Categories_Column, i18n("Categories"));
+    d->mTreeWidget->headerItem()->setText(Categories_Column, i18n("Tags"));
 
     d->mTreeWidget->setWordWrap(true);
     d->mTreeWidget->setAllColumnsShowFocus(true);
@@ -321,23 +294,21 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, b
     layoutTop->setContentsMargins(0, 0, 0, 0);
     layoutTop->addWidget(d->mTreeWidget);
 
-    QObject::connect(d->mTreeWidget, QOverload<const QModelIndex &>::of(&QTreeWidget::doubleClicked), this,
-                     QOverload<const QModelIndex &>::of(&ListView::defaultItemAction));
     QObject::connect(d->mTreeWidget,
-                     &QTreeWidget::customContextMenuRequested,
-                     this, &ListView::popupMenu);
-    QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged,
-                     this, &ListView::processSelectionChange);
+                     qOverload<const QModelIndex &>(&QTreeWidget::doubleClicked),
+                     this,
+                     qOverload<const QModelIndex &>(&ListView::defaultItemAction));
+    QObject::connect(d->mTreeWidget, &QTreeWidget::customContextMenuRequested, this, &ListView::popupMenu);
+    QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged, this, &ListView::processSelectionChange);
+    QObject::connect(d->mTreeWidget->header(), &QHeaderView::sortIndicatorChanged,
+                     this, &ListView::slotSortIndicatorChanged);
 
     d->mSelectedDates.append(QDate::currentDate());
 
     updateView();
 }
 
-ListView::~ListView()
-{
-    delete d;
-}
+ListView::~ListView() = default;
 
 int ListView::currentDateCount() const
 {
@@ -347,10 +318,9 @@ int ListView::currentDateCount() const
 Akonadi::Item::List ListView::selectedIncidences() const
 {
     Akonadi::Item::List eventList;
-    QTreeWidgetItem *item = d->mTreeWidget->selectedItems().isEmpty() ? nullptr
-                            : d->mTreeWidget->selectedItems().first();
+    QTreeWidgetItem *item = d->mTreeWidget->selectedItems().isEmpty() ? nullptr : d->mTreeWidget->selectedItems().first();
     if (item) {
-        ListViewItem *i = static_cast<ListViewItem *>(item);
+        auto i = static_cast<ListViewItem *>(item);
         eventList.append(i->mIncidence);
     }
     return eventList;
@@ -367,18 +337,18 @@ void ListView::updateView()
 
     /* Set the width of the summary column to show 'maxlen' chars, at most */
     int width = qMin(maxLen * fontMetrics().averageCharWidth(), maxLen * 12);
-    width += 24; //for the icon
+    width += 24; // for the icon
 
     d->mTreeWidget->setColumnWidth(Summary_Column, width);
     for (int col = StartDateTime_Column; col < Dummy_EOF_Column; ++col) {
         d->mTreeWidget->resizeColumnToContents(col);
     }
-    d->mTreeWidget->sortItems(StartDateTime_Column, Qt::AscendingOrder);
+    d->mTreeWidget->sortItems(d->mSortColumn, d->mSortOrder);
 }
 
 void ListView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
-    Q_UNUSED(preferredMonth);
+    Q_UNUSED(preferredMonth)
     clear();
 
     d->mStartDate = start;
@@ -387,8 +357,7 @@ void ListView::showDates(const QDate &start, const QDate &end, const QDate &pref
     const QString startStr = QLocale().toString(start, QLocale::ShortFormat);
     const QString endStr = QLocale().toString(end, QLocale::ShortFormat);
 
-    d->mTreeWidget->headerItem()->setText(Summary_Column,
-                                          i18n("Summary [%1 - %2]", startStr, endStr));
+    d->mTreeWidget->headerItem()->setText(Summary_Column, i18n("Summary [%1 - %2]", startStr, endStr));
 
     QDate date = start;
     while (date <= end) {
@@ -407,17 +376,14 @@ void ListView::showAll()
     d->addIncidences(calendar(), calendar()->incidences(), QDate());
 }
 
-void ListView::Private::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar,
-                                      const KCalendarCore::Incidence::List &incidences,
-                                      const QDate &date)
+void ListViewPrivate::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidences, QDate date)
 {
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         addIncidence(calendar, incidence, date);
     }
 }
 
-void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                                     const Akonadi::Item &item, const QDate &date)
+void ListViewPrivate::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &item, QDate date)
 {
     Q_ASSERT(calendar);
     if (item.isValid() && item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
@@ -425,8 +391,7 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
     }
 }
 
-void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
-                                     const KCalendarCore::Incidence::Ptr &incidence, const QDate &date)
+void ListViewPrivate::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
     if (!incidence) {
         return;
@@ -442,26 +407,20 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
     mItems.insert(aitem.id(), aitem);
     Incidence::Ptr tinc = incidence;
 
-    if (tinc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")
-        || tinc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
+    if (tinc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES") || tinc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
         const int years = EventViews::yearDiff(tinc->dtStart().date(), mEndDate);
         if (years > 0) {
             tinc = Incidence::Ptr(incidence->clone());
             tinc->setReadOnly(false);
-            tinc->setSummary(i18np("%2 (1 year)", "%2 (%1 years)", years,
-                                   cleanSummary(incidence->summary(), QDateTime())));
+            tinc->setSummary(i18np("%2 (1 year)", "%2 (%1 years)", years, cleanSummary(incidence->summary(), QDateTime())));
             tinc->setReadOnly(true);
         }
     }
-    ListViewItem *item = new ListViewItem(aitem, mTreeWidget);
+    auto item = new ListViewItem(aitem, mTreeWidget);
 
     // set tooltips
     for (int col = 0; col < Dummy_EOF_Column; ++col) {
-        item->setToolTip(col,
-                         IncidenceFormatter::toolTipStr(
-                             CalendarSupport::displayName(calendar.data(),
-                                                          aitem.parentCollection()),
-                             incidence));
+        item->setToolTip(col, IncidenceFormatter::toolTipStr(CalendarSupport::displayName(calendar.data(), aitem.parentCollection()), incidence));
     }
 
     ListItemVisitor v(item, mStartDate);
@@ -487,8 +446,8 @@ void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
 {
     const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
     ListViewItem *item = nullptr;
-    QDate f = d->mSelectedDates.first();
-    QDate l = d->mSelectedDates.last();
+    const QDate f = d->mSelectedDates.constFirst();
+    const QDate l = d->mSelectedDates.constLast();
 
     QDate date;
     if (CalendarSupport::hasTodo(aitem)) {
@@ -523,11 +482,11 @@ void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
     }
 }
 
-ListViewItem *ListView::Private::getItemForIncidence(const Akonadi::Item &aitem)
+ListViewItem *ListViewPrivate::getItemForIncidence(const Akonadi::Item &aitem)
 {
     int index = 0;
     while (QTreeWidgetItem *it = mTreeWidget->topLevelItem(index)) {
-        ListViewItem *item = static_cast<ListViewItem *>(it);
+        auto item = static_cast<ListViewItem *>(it);
         if (item->mIncidence.id() == aitem.id()) {
             return item;
         }
@@ -537,6 +496,12 @@ ListViewItem *ListView::Private::getItemForIncidence(const Akonadi::Item &aitem)
     return nullptr;
 }
 
+void ListView::slotSortIndicatorChanged(int logicalIndex, Qt::SortOrder order)
+{
+    d->mSortColumn = logicalIndex;
+    d->mSortOrder = order;
+}
+
 void ListView::defaultItemAction(const QModelIndex &index)
 {
     if (!d->mIsNonInteractive) {
@@ -563,8 +528,7 @@ void ListView::popupMenu(const QPoint &point)
         // FIXME: For recurring incidences we don't know the date of this
         // occurrence, there's no reference to it at all!
 
-        Q_EMIT showIncidencePopupSignal(aitem,
-                                        CalendarSupport::incidence(aitem)->dtStart().date());
+        Q_EMIT showIncidencePopupSignal(aitem, CalendarSupport::incidence(aitem)->dtStart().date());
     } else {
         Q_EMIT showNewEventPopupSignal();
     }
@@ -573,16 +537,28 @@ void ListView::popupMenu(const QPoint &point)
 void ListView::readSettings(KConfig *config)
 {
     KConfigGroup cfgGroup = config->group("ListView Layout");
+    readSettings(cfgGroup);
+}
+
+void EventViews::ListView::readSettings(const KConfigGroup &cfgGroup)
+{
     const QByteArray state = cfgGroup.readEntry("ViewState", QByteArray());
     d->mTreeWidget->header()->restoreState(state);
+    d->mSortColumn = cfgGroup.readEntry("SortColumn", static_cast<int>(StartDateTime_Column));
+    d->mSortOrder = static_cast<Qt::SortOrder>(cfgGroup.readEntry("SortOrder", static_cast<int>(Qt::AscendingOrder)));
 }
 
 void ListView::writeSettings(KConfig *config)
 {
-    const QByteArray state = d->mTreeWidget->header()->saveState();
     KConfigGroup cfgGroup = config->group("ListView Layout");
+}
 
+void EventViews::ListView::writeSettings(KConfigGroup &cfgGroup)
+{
+    const QByteArray state = d->mTreeWidget->header()->saveState();
     cfgGroup.writeEntry("ViewState", state);
+    cfgGroup.writeEntry("SortColumn", d->mSortColumn);
+    cfgGroup.writeEntry("SortOrder", static_cast<int>(d->mSortOrder));
 }
 
 void ListView::processSelectionChange()
@@ -619,6 +595,5 @@ void ListView::clear()
 QSize ListView::sizeHint() const
 {
     const QSize s = EventView::sizeHint();
-    return QSize(s.width() + style()->pixelMetric(QStyle::PM_ScrollBarExtent) + 1,
-                 s.height());
+    return {s.width() + style()->pixelMetric(QStyle::PM_ScrollBarExtent) + 1, s.height()};
 }
