@@ -1,47 +1,33 @@
 /*
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef EVENTVIEWS_LISTVIEW_H
-#define EVENTVIEWS_LISTVIEW_H
+#pragma once
 
 #include "eventview.h"
 
+#include <memory>
+
 class KConfig;
 
 class QModelIndex;
 
+namespace EventViews
+{
+class ListViewPrivate;
+
 /**
   This class provides a multi-column list view of events.  It can
   display events from one particular day or several days, it doesn't
-  matter.  To use a view that only handles one day at a time, use
-  KODayListView.
+  matter.
 
   @short multi-column list view of various events.
   @author Preston Brown <pbrown@kde.org>
-  @see KOBaseView, KODayListView
+  @see EventView
 */
-
-namespace EventViews {
 class EVENTVIEWS_EXPORT ListView : public EventView
 {
     Q_OBJECT
@@ -56,9 +42,30 @@ public:
     // Shows all incidences of the calendar
     void showAll();
 
+    /**
+     * Read settings from the "ListView Layout" group of the configuration.
+     * @deprecated Use readSettings with a specific KConfigGroup.
+     */
     void readSettings(KConfig *config);
+
+    /**
+     * Read settings from the given configuration group.
+     * @since 5.18.1
+     */
+    void readSettings(const KConfigGroup &cfgGroup);
+
+    /**
+     * Write settings to the "ListView Layout" group of the configuration.
+     * @deprecated Use writeSettings with a specific KConfigGroup.
+     */
     void writeSettings(KConfig *config);
 
+    /**
+     * Write settings to the given configuration group.
+     * @since 5.18.1
+     */
+    void writeSettings(KConfigGroup &cfgGroup);
+
     void clear();
     QSize sizeHint() const override;
 
@@ -86,9 +93,9 @@ protected Q_SLOTS:
     void processSelectionChange();
 
 private:
-    class Private;
-    Private *const d;
+    void slotSortIndicatorChanged(int logicalIndex, Qt::SortOrder order);
+
+    std::unique_ptr<ListViewPrivate> const d;
 };
 }
 
-#endif
