@@ -5,13 +5,13 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef EVENTVIEWS_MONTHGRAPHICSITEMS_H
-#define EVENTVIEWS_MONTHGRAPHICSITEMS_H
+#pragma once
 
 #include <QDate>
 #include <QGraphicsItem>
 
-namespace EventViews {
+namespace EventViews
+{
 class MonthItem;
 
 /**
@@ -21,10 +21,7 @@ class MonthItem;
 class ScrollIndicator : public QGraphicsItem
 {
 public:
-    enum ArrowDirection {
-        UpArrow,
-        DownArrow
-    };
+    enum ArrowDirection { UpArrow, DownArrow };
 
     explicit ScrollIndicator(ArrowDirection direction);
 
@@ -49,7 +46,7 @@ private:
 class MonthCell
 {
 public:
-    MonthCell(int id, const QDate &date, QGraphicsScene *scene);
+    MonthCell(int id, QDate date, QGraphicsScene *scene);
     ~MonthCell();
 
     /**
@@ -118,10 +115,10 @@ class MonthGraphicsItem : public QObject, public QGraphicsItem
     Q_INTERFACES(QGraphicsItem)
 
 public:
-    typedef QList<MonthGraphicsItem *> List;
+    using List = QList<MonthGraphicsItem *>;
 
     explicit MonthGraphicsItem(MonthItem *manager);
-    ~MonthGraphicsItem();
+    ~MonthGraphicsItem() override;
 
     /**
       Change QGraphicsItem pos and boundingRect in the scene
@@ -204,4 +201,3 @@ private:
 };
 }
 
-#endif
