@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthitem.h"
@@ -35,17 +19,14 @@
 #include <KCalUtils/IncidenceFormatter>
 #include <KCalUtils/RecurrenceActions>
 
-#include <KMessageBox>
 #include "calendarview_debug.h"
+#include <KMessageBox>
 
 using namespace EventViews;
 using namespace KCalendarCore;
 
 MonthItem::MonthItem(MonthScene *monthScene)
     : mMonthScene(monthScene)
-    , mSelected(false)
-    , mMoving(false)
-    , mResizing(false)
 {
 }
 
@@ -76,22 +57,21 @@ void MonthItem::updateMonthGraphicsItems()
 
     // For each row of the month view, create an item to build the whole
     // MonthItem's MonthGraphicsItems.
-    for (QDate d = mMonthScene->mMonthView->actualStartDateTime().date();
-         d < mMonthScene->mMonthView->actualEndDateTime().date(); d = d.addDays(7)) {
+    for (QDate d = mMonthScene->mMonthView->actualStartDateTime().date(); d < mMonthScene->mMonthView->actualEndDateTime().date(); d = d.addDays(7)) {
         QDate end = d.addDays(6);
 
         int span;
         QDate start;
-        if (monthStartDate <= d && monthEndDate >= end) {   // MonthItem takes the whole line
+        if (monthStartDate <= d && monthEndDate >= end) { // MonthItem takes the whole line
             span = 6;
             start = d;
-        } else if (monthStartDate >= d && monthEndDate <= end) {   // starts and ends on this line
+        } else if (monthStartDate >= d && monthEndDate <= end) { // starts and ends on this line
             start = monthStartDate;
             span = daySpan();
-        } else if (d <= monthEndDate && monthEndDate <= end) {   // MonthItem ends on this line
+        } else if (d <= monthEndDate && monthEndDate <= end) { // MonthItem ends on this line
             span = mMonthScene->getLeftSpan(monthEndDate);
             start = d;
-        } else if (d <= monthStartDate && monthStartDate <= end) {   // MonthItem begins on this line
+        } else if (d <= monthStartDate && monthStartDate <= end) { // MonthItem begins on this line
             span = mMonthScene->getRightSpan(monthStartDate);
             start = monthStartDate;
         } else { // MonthItem is not on the line
@@ -99,7 +79,7 @@ void MonthItem::updateMonthGraphicsItems()
         }
 
         // A new item needs to be created
-        MonthGraphicsItem *newItem = new MonthGraphicsItem(this);
+        auto newItem = new MonthGraphicsItem(this);
         mMonthGraphicsItemList << newItem;
         newItem->setStartDate(start);
         newItem->setDaySpan(span);
@@ -178,14 +158,14 @@ void MonthItem::moveBy(int offsetToPreviousDate)
 
 void MonthItem::updateGeometry()
 {
-    for (MonthGraphicsItem *item : qAsConst(mMonthGraphicsItemList)) {
+    for (MonthGraphicsItem *item : std::as_const(mMonthGraphicsItemList)) {
         item->updateGeometry();
     }
 }
 
 void MonthItem::setZValue(qreal z)
 {
-    for (MonthGraphicsItem *item : qAsConst(mMonthGraphicsItemList)) {
+    for (MonthGraphicsItem *item : std::as_const(mMonthGraphicsItemList)) {
         item->setZValue(z);
     }
 }
@@ -213,13 +193,8 @@ int MonthItem::daySpan() const
     if (isMoving() || isResizing()) {
         return mOverrideDaySpan;
     }
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    QDateTime start(startDate());
-    QDateTime end(endDate());
-#else
     QDateTime start(startDate().startOfDay());
     QDateTime end(endDate().startOfDay());
-#endif
 
     if (start.isValid() && end.isValid()) {
         return start.daysTo(end);
@@ -230,17 +205,15 @@ int MonthItem::daySpan() const
 
 bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
 {
-    const QDate leftStartDate = e1->startDate();
-    const QDate rightStartDate = e2->startDate();
-
-    if (!leftStartDate.isValid() || !rightStartDate.isValid()) {
-        return false;
-    }
-
-    if (leftStartDate == rightStartDate) {
-        const int leftDaySpan = e1->daySpan();
-        const int rightDaySpan = e2->daySpan();
-        if (leftDaySpan == rightDaySpan) {
+    const int leftDaySpan = e1->daySpan();
+    const int rightDaySpan = e2->daySpan();
+    if (leftDaySpan == rightDaySpan) {
+        const QDate leftStartDate = e1->startDate();
+        const QDate rightStartDate = e2->startDate();
+        if (!leftStartDate.isValid() || !rightStartDate.isValid()) {
+            return false;
+        }
+        if (leftStartDate == rightStartDate) {
             if (e1->allDay() && !e2->allDay()) {
                 return true;
             }
@@ -249,16 +222,15 @@ bool MonthItem::greaterThan(const MonthItem *e1, const MonthItem *e2)
             }
             return e1->greaterThanFallback(e2);
         } else {
-            return leftDaySpan > rightDaySpan;
+            return leftStartDate > rightStartDate;
         }
     }
-
-    return leftStartDate > rightStartDate;
+    return leftDaySpan > rightDaySpan;
 }
 
 bool MonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const HolidayMonthItem *h = qobject_cast<const HolidayMonthItem *>(other);
+    const auto h = qobject_cast<const HolidayMonthItem *>(other);
 
     // If "other" is a holiday, display it first.
     return !h;
@@ -300,8 +272,11 @@ QList<MonthGraphicsItem *> EventViews::MonthItem::monthGraphicsItems() const
 
 //-----------------------------------------------------------------
 // INCIDENCEMONTHITEM
-IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &aitem, const KCalendarCore::Incidence::Ptr &incidence,
-                                       const QDate &recurStartDate)
+IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene,
+                                       const Akonadi::ETMCalendar::Ptr &calendar,
+                                       const Akonadi::Item &aitem,
+                                       const KCalendarCore::Incidence::Ptr &incidence,
+                                       QDate recurStartDate)
     : MonthItem(monthScene)
     , mCalendar(calendar)
     , mIncidence(incidence)
@@ -312,8 +287,7 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ET
     mIsTodo = CalendarSupport::hasTodo(aitem);
 
     KCalendarCore::Incidence::Ptr inc = mIncidence;
-    if (inc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES")
-        || inc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
+    if (inc->customProperty("KABC", "BIRTHDAY") == QLatin1String("YES") || inc->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
         const int years = EventViews::yearDiff(inc->dtStart().date(), recurStartDate);
         if (years > 0) {
             inc = KCalendarCore::Incidence::Ptr(inc->clone());
@@ -324,14 +298,13 @@ IncidenceMonthItem::IncidenceMonthItem(MonthScene *monthScene, const Akonadi::ET
         }
     }
 
-    connect(monthScene, &MonthScene::incidenceSelected,
-            this, &IncidenceMonthItem::updateSelection);
+    connect(monthScene, &MonthScene::incidenceSelected, this, &IncidenceMonthItem::updateSelection);
 
     // first set to 0, because it's used in startDate()
     mRecurDayOffset = 0;
-    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid())
-        && startDate().isValid() && recurStartDate.isValid()) {
-        mRecurDayOffset = startDate().daysTo(recurStartDate);
+    const auto incidenceStart = mIncidence->dtStart().toLocalTime().date();
+    if ((mIncidence->recurs() || mIncidence->recurrenceId().isValid()) && incidenceStart.isValid() && recurStartDate.isValid()) {
+        mRecurDayOffset = incidenceStart.daysTo(recurStartDate);
     }
 }
 
@@ -341,7 +314,7 @@ IncidenceMonthItem::~IncidenceMonthItem()
 
 bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const IncidenceMonthItem *o = qobject_cast<const IncidenceMonthItem *>(other);
+    const auto o = qobject_cast<const IncidenceMonthItem *>(other);
     if (!o) {
         return MonthItem::greaterThanFallback(other);
     }
@@ -362,7 +335,7 @@ bool IncidenceMonthItem::greaterThanFallback(const MonthItem *other) const
 QDate IncidenceMonthItem::realStartDate() const
 {
     if (!mIncidence) {
-        return QDate();
+        return {};
     }
 
     const QDateTime dt = mIncidence->dateTime(Incidence::RoleDisplayStart);
@@ -374,10 +347,15 @@ QDate IncidenceMonthItem::realStartDate() const
 QDate IncidenceMonthItem::realEndDate() const
 {
     if (!mIncidence) {
-        return QDate();
+        return {};
     }
 
-    const QDateTime dt = mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayEnd);
+    QDateTime dt = mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayEnd);
+    if (!mIncidence->allDay() && dt > mIncidence->dateTime(KCalendarCore::Incidence::RoleDisplayStart)) {
+        // If dt's time portion is 00:00:00, the incidence ends on the previous day
+        // unless it also starts at 00:00:00 (a duration of 0).
+        dt = dt.addMSecs(-1);
+    }
     const QDate end = dt.toLocalTime().date();
 
     return end.addDays(mRecurDayOffset);
@@ -390,15 +368,12 @@ bool IncidenceMonthItem::allDay() const
 
 bool IncidenceMonthItem::isMoveable() const
 {
-    return monthScene()->mMonthView->calendar()->hasRight(akonadiItem(),
-                                                          Akonadi::Collection::CanChangeItem);
+    return monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
 }
 
 bool IncidenceMonthItem::isResizable() const
 {
-    return mIsEvent && monthScene()->mMonthView->calendar()->hasRight(
-        akonadiItem(),
-        Akonadi::Collection::CanChangeItem);
+    return mIsEvent && monthScene()->mMonthView->calendar()->hasRight(akonadiItem(), Akonadi::Collection::CanChangeItem);
 }
 
 void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
@@ -406,8 +381,7 @@ void IncidenceMonthItem::finalizeMove(const QDate &newStartDate)
     Q_ASSERT(isMoveable());
 
     if (startDate().isValid() && newStartDate.isValid()) {
-        updateDates(startDate().daysTo(newStartDate),
-                    startDate().daysTo(newStartDate));
+        updateDates(startDate().daysTo(newStartDate), startDate().daysTo(newStartDate));
     }
 }
 
@@ -415,10 +389,8 @@ void IncidenceMonthItem::finalizeResize(const QDate &newStartDate, const QDate &
 {
     Q_ASSERT(isResizable());
 
-    if (startDate().isValid() && endDate().isValid()
-        && newStartDate.isValid() && newEndDate.isValid()) {
-        updateDates(startDate().daysTo(newStartDate),
-                    endDate().daysTo(newEndDate));
+    if (startDate().isValid() && endDate().isValid() && newStartDate.isValid() && newEndDate.isValid()) {
+        updateDates(startDate().daysTo(newStartDate), endDate().daysTo(newEndDate));
     }
 }
 
@@ -435,8 +407,7 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
     if (mIncidence->recurs()) {
         const int res = monthScene()->mMonthView->showMoveRecurDialog(mIncidence, startDate());
         switch (res) {
-        case KCalUtils::RecurrenceActions::AllOccurrences:
-        {
+        case KCalUtils::RecurrenceActions::AllOccurrences: {
             // All occurrences
             KCalendarCore::Incidence::Ptr oldIncidence(mIncidence->clone());
             setNewDates(mIncidence, startOffset, endOffset);
@@ -444,24 +415,21 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
             break;
         }
         case KCalUtils::RecurrenceActions::SelectedOccurrence: // Just this occurrence
-        case KCalUtils::RecurrenceActions::FutureOccurrences:
-        {                                                       // All future occurrences
+        case KCalUtils::RecurrenceActions::FutureOccurrences: { // All future occurrences
             const bool thisAndFuture = (res == KCalUtils::RecurrenceActions::FutureOccurrences);
             QDateTime occurrenceDate(mIncidence->dtStart());
             occurrenceDate.setDate(startDate());
-            KCalendarCore::Incidence::Ptr newIncidence(KCalendarCore::Calendar::createException(
-                                                      mIncidence, occurrenceDate, thisAndFuture));
+            KCalendarCore::Incidence::Ptr newIncidence(KCalendarCore::Calendar::createException(mIncidence, occurrenceDate, thisAndFuture));
             if (newIncidence) {
                 changer->startAtomicOperation(i18n("Move occurrence(s)"));
                 setNewDates(newIncidence, startOffset, endOffset);
                 changer->createIncidence(newIncidence, item.parentCollection(), parentWidget());
                 changer->endAtomicOperation();
             } else {
-                KMessageBox::sorry(
-                    parentWidget(),
-                    i18n("Unable to add the exception item to the calendar. "
-                         "No change will be done."),
-                    i18n("Error Occurred"));
+                KMessageBox::sorry(parentWidget(),
+                                   i18n("Unable to add the exception item to the calendar. "
+                                        "No change will be done."),
+                                   i18n("Error Occurred"));
             }
             break;
         }
@@ -473,17 +441,16 @@ void IncidenceMonthItem::updateDates(int startOffset, int endOffset)
     }
 }
 
-void IncidenceMonthItem::updateSelection(const Akonadi::Item &incidence, const QDate &date)
+void IncidenceMonthItem::updateSelection(const Akonadi::Item &incidence, QDate date)
 {
-    Q_UNUSED(date);
+    Q_UNUSED(date)
     setSelected(incidence == akonadiItem());
 }
 
 QString IncidenceMonthItem::text(bool end) const
 {
     QString ret = mIncidence->summary();
-    if (!allDay() && !mIsJournal
-        && monthScene()->monthView()->preferences()->showTimeInMonthView()) {
+    if (!allDay() && !mIsJournal && monthScene()->monthView()->preferences()->showTimeInMonthView()) {
         // Prepend the time str to the text
         QString timeStr;
         if (mIsTodo) {
@@ -501,8 +468,7 @@ QString IncidenceMonthItem::text(bool end) const
                 timeStr = QLocale().toString(time, QLocale::ShortFormat);
             } else {
                 KCalendarCore::Event::Ptr event = mIncidence.staticCast<Event>();
-                timeStr = QLocale().toString(
-                    event->dtEnd().toLocalTime().time(), QLocale::ShortFormat);
+                timeStr = QLocale().toString(event->dtEnd().toLocalTime().time(), QLocale::ShortFormat);
             }
         }
         if (!timeStr.isEmpty()) {
@@ -519,9 +485,7 @@ QString IncidenceMonthItem::text(bool end) const
 
 QString IncidenceMonthItem::toolTipText(const QDate &date) const
 {
-    return KCalUtils::IncidenceFormatter::toolTipStr(
-        CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()),
-        mIncidence, date, true);
+    return KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(mCalendar.data(), akonadiItem().parentCollection()), mIncidence, date, true);
 }
 
 QVector<QPixmap> IncidenceMonthItem::icons() const
@@ -535,14 +499,12 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
     bool specialEvent = false;
     Akonadi::Item item = akonadiItem();
 
-    const QSet<EventView::ItemIcon> icons
-        = monthScene()->monthView()->preferences()->monthViewIcons();
+    const QSet<EventView::ItemIcon> icons = monthScene()->monthView()->preferences()->monthViewIcons();
 
     QString customIconName;
     if (icons.contains(EventViews::EventView::CalendarCustomIcon)) {
         const QString iconName = monthScene()->monthView()->iconForItem(item);
-        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar")
-            && iconName != QLatin1String("office-calendar")) {
+        if (!iconName.isEmpty() && iconName != QLatin1String("view-calendar") && iconName != QLatin1String("office-calendar")) {
             customIconName = iconName;
             ret << QPixmap(cachedSmallIcon(iconName));
         }
@@ -556,7 +518,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
             specialEvent = true;
             // Disabling birthday icon because it's the birthday agent's icon
             // and we allow to display the agent's icon now.
-            //ret << monthScene()->birthdayPixmap();
+            // ret << monthScene()->birthdayPixmap();
         }
 
         // smartins: Disabling the event Pixmap because:
@@ -567,9 +529,7 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
         //    from event's much easier.
 
         // ret << monthScene()->eventPixmap();
-    } else if ((mIsTodo || mIsJournal) && icons.contains(mIsTodo
-                                                         ? EventView::TaskIcon
-                                                         : EventView::JournalIcon)) {
+    } else if ((mIsTodo || mIsJournal) && icons.contains(mIsTodo ? EventView::TaskIcon : EventView::JournalIcon)) {
         QDateTime occurrenceDateTime = mIncidence->dateTime(Incidence::RoleRecurrenceStart);
         occurrenceDateTime.setDate(realStartDate());
 
@@ -579,23 +539,19 @@ QVector<QPixmap> IncidenceMonthItem::icons() const
         }
     }
 
-    if (icons.contains(EventView::ReadOnlyIcon)
-        && !monthScene()->mMonthView->calendar()->hasRight(item, Akonadi::Collection::CanChangeItem)
-        && !specialEvent) {
+    if (icons.contains(EventView::ReadOnlyIcon) && !monthScene()->mMonthView->calendar()->hasRight(item, Akonadi::Collection::CanChangeItem) && !specialEvent) {
         ret << monthScene()->readonlyPixmap();
     }
 
     /* sorry, this looks too cluttered. disable until we can
        make something prettier; no idea at this time -- allen */
-    if (icons.contains(EventView::ReminderIcon)
-        && mIncidence->hasEnabledAlarms() && !specialEvent) {
+    if (icons.contains(EventView::ReminderIcon) && mIncidence->hasEnabledAlarms() && !specialEvent) {
         ret << monthScene()->alarmPixmap();
     }
-    if (icons.contains(EventView::RecurringIcon)
-        && mIncidence->recurs() && !specialEvent) {
+    if (icons.contains(EventView::RecurringIcon) && mIncidence->recurs() && !specialEvent) {
         ret << monthScene()->recurPixmap();
     }
-    //TODO: check what to do with Reply
+    // TODO: check what to do with Reply
 
     return ret;
 }
@@ -639,8 +595,7 @@ QColor IncidenceMonthItem::bgColor() const
     }
 
     const auto &colorPreference = prefs->monthViewColors();
-    const auto bgDisplaysResource = colorPreference == PrefsBase::MonthItemResourceInsideCategoryOutside
-                                    || colorPreference == PrefsBase::MonthItemResourceOnly;
+    const auto bgDisplaysResource = colorPreference == PrefsBase::MonthItemResourceInsideCategoryOutside || colorPreference == PrefsBase::MonthItemResourceOnly;
     return bgDisplaysResource ? EventViews::resourceColor(akonadiItem(), prefs) : catColor();
 }
 
@@ -648,8 +603,7 @@ QColor IncidenceMonthItem::frameColor() const
 {
     const auto &prefs = monthScene()->monthView()->preferences();
     const auto frameDisplaysResource =
-        (prefs->monthViewColors() == PrefsBase::MonthItemResourceOnly
-         || prefs->monthViewColors() == PrefsBase::MonthItemCategoryInsideResourceOutside);
+        (prefs->monthViewColors() == PrefsBase::MonthItemResourceOnly || prefs->monthViewColors() == PrefsBase::MonthItemCategoryInsideResourceOutside);
     const auto frameColor = frameDisplaysResource ? EventViews::resourceColor(akonadiItem(), prefs) : catColor();
     return EventView::itemFrameColor(frameColor, selected());
 }
@@ -684,7 +638,7 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
         KCalendarCore::Todo::Ptr todo = incidence.staticCast<Todo>();
         QDateTime due = todo->dtDue();
         QDateTime start = todo->dtStart();
-        if (due.isValid()) {   // Due has priority over start.
+        if (due.isValid()) { // Due has priority over start.
             // We will only move the due date, unlike events where we move both.
             due = due.addDays(offset);
             todo->setDtDue(due);
@@ -699,8 +653,7 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
             todo->setDtStart(start);
         } else {
             // This never happens
-            qCWarning(CALENDARVIEW_LOG) << "Move what? uid:" << todo->uid() << "; summary="
-                                        << todo->summary();
+            qCWarning(CALENDARVIEW_LOG) << "Move what? uid:" << todo->uid() << "; summary=" << todo->summary();
         }
     } else {
         incidence->setDtStart(incidence->dtStart().addDays(startOffset));
@@ -713,9 +666,15 @@ void IncidenceMonthItem::setNewDates(const KCalendarCore::Incidence::Ptr &incide
 
 //-----------------------------------------------------------------
 // HOLIDAYMONTHITEM
-HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, const QDate &date, const QString &name)
+HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate date, const QString &name)
+    : HolidayMonthItem(monthScene, date, date, name)
+{
+}
+
+HolidayMonthItem::HolidayMonthItem(MonthScene *monthScene, QDate startDate, QDate endDate, const QString &name)
     : MonthItem(monthScene)
-    , mDate(date)
+    , mStartDate(startDate)
+    , mEndDate(endDate)
     , mName(name)
 {
 }
@@ -726,25 +685,21 @@ HolidayMonthItem::~HolidayMonthItem()
 
 bool HolidayMonthItem::greaterThanFallback(const MonthItem *other) const
 {
-    const HolidayMonthItem *o = qobject_cast<const HolidayMonthItem *>(other);
-    if (o) {
-        return MonthItem::greaterThanFallback(other);
-    }
-
+    const auto o = qobject_cast<const HolidayMonthItem *>(other);
     // always put holidays on top
-    return false;
+    return !o;
 }
 
 void HolidayMonthItem::finalizeMove(const QDate &newStartDate)
 {
-    Q_UNUSED(newStartDate);
+    Q_UNUSED(newStartDate)
     Q_ASSERT(false);
 }
 
 void HolidayMonthItem::finalizeResize(const QDate &newStartDate, const QDate &newEndDate)
 {
-    Q_UNUSED(newStartDate);
-    Q_UNUSED(newEndDate);
+    Q_UNUSED(newStartDate)
+    Q_UNUSED(newEndDate)
     Q_ASSERT(false);
 }
 
