@@ -1,39 +1,24 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "monthscene.h"
+#include "helper.h"
 #include "monthgraphicsitems.h"
 #include "monthitem.h"
 #include "monthview.h"
-#include "helper.h"
 #include "prefs.h"
 
 #include <CalendarSupport/Utils>
 
-#include <QGraphicsSceneMouseEvent>
-#include <QResizeEvent>
+#include <KColorScheme>
 #include <KLocalizedString>
-#include <QToolTip>
+#include <QGraphicsSceneMouseEvent>
 #include <QIcon>
+#include <QResizeEvent>
+#include <QToolTip>
 
 static const int AUTO_REPEAT_DELAY = 600;
 
@@ -54,8 +39,7 @@ MonthScene::MonthScene(MonthView *parent)
     , mCurrentIndicator(nullptr)
 {
     mBirthdayPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-birthday")).pixmap(16, 16);
-    mAnniversaryPixmap
-        = QIcon::fromTheme(QStringLiteral("view-calendar-wedding-anniversary")).pixmap(16, 16);
+    mAnniversaryPixmap = QIcon::fromTheme(QStringLiteral("view-calendar-wedding-anniversary")).pixmap(16, 16);
     mAlarmPixmap = QIcon::fromTheme(QStringLiteral("appointment-reminder")).pixmap(16, 16);
     mRecurPixmap = QIcon::fromTheme(QStringLiteral("appointment-recurring")).pixmap(16, 16);
     mReadonlyPixmap = QIcon::fromTheme(QStringLiteral("object-locked")).pixmap(16, 16);
@@ -81,7 +65,7 @@ MonthCell *MonthScene::previousCell() const
     return mPreviousCell;
 }
 
-int MonthScene::getRightSpan(const QDate &date) const
+int MonthScene::getRightSpan(QDate date) const
 {
     MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
@@ -91,7 +75,7 @@ int MonthScene::getRightSpan(const QDate &date) const
     return 7 - cell->x() - 1;
 }
 
-int MonthScene::getLeftSpan(const QDate &date) const
+int MonthScene::getLeftSpan(QDate date) const
 {
     MonthCell *cell = mMonthCellMap.value(date);
     if (!cell) {
@@ -130,7 +114,7 @@ MonthCell *MonthScene::firstCellForMonthItem(MonthItem *manager)
 
 void MonthScene::updateGeometry()
 {
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 }
@@ -183,6 +167,7 @@ int MonthScene::sceneXToMonthGridX(int xScene)
 void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
 {
     Q_ASSERT(mScene);
+
     PrefsPtr prefs = mScene->monthView()->preferences();
     p->setFont(prefs->monthViewFont());
     p->fillRect(rect, palette().color(QPalette::Window));
@@ -195,7 +180,8 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     font.setPointSize(15);
     p->setFont(font);
     const int dayLabelsHeight = 20;
-    p->drawText(QRect(0, 0,    // top right
+    p->drawText(QRect(0,
+                      0, // top right
                       static_cast<int>(mScene->sceneRect().width()),
                       static_cast<int>(mScene->headerHeight() - dayLabelsHeight)),
                 Qt::AlignCenter,
@@ -207,9 +193,8 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     const QDate start = mMonthView->actualStartDateTime().date();
     const QDate end = mMonthView->actualEndDateTime().date();
 
-    for (QDate d = start;
-         d <= start.addDays(6); d = d.addDays(1)) {
-        MonthCell *cell = mScene->mMonthCellMap.value(d);
+    for (QDate d = start; d <= start.addDays(6); d = d.addDays(1)) {
+        const MonthCell *const cell = mScene->mMonthCellMap.value(d);
 
         if (!cell) {
             // This means drawBackground() is being called before reloadIncidences(). Can happen with some
@@ -217,10 +202,7 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
             return;
         }
 
-        p->drawText(QRect(mScene->cellHorizontalPos(cell),
-                          mScene->cellVerticalPos(cell) - 15,
-                          mScene->columnWidth(),
-                          15),
+        p->drawText(QRect(mScene->cellHorizontalPos(cell), mScene->cellVerticalPos(cell) - 15, mScene->columnWidth(), 15),
                     Qt::AlignCenter,
                     QLocale::system().dayName(d.dayOfWeek(), QLocale::LongFormat));
     }
@@ -230,101 +212,94 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
     */
     int columnWidth = mScene->columnWidth();
     int rowHeight = mScene->rowHeight();
+    QDate todayDate {QDate::currentDate()};
 
-    const QList<QDate> workDays = CalendarSupport::workDays(
-        mMonthView->actualStartDateTime().date(),
-        mMonthView->actualEndDateTime().date());
+    const QList<QDate> workDays = CalendarSupport::workDays(mMonthView->actualStartDateTime().date(), mMonthView->actualEndDateTime().date());
+    QRect todayRect;
+    QRect selectedRect;
+    QColor holidayBg;
+    QColor workdayBg;
+    if (mMonthView->preferences()->useSystemColor()) {
+        workdayBg = palette().color(QPalette::Base);
+        holidayBg = palette().color(QPalette::AlternateBase);
+    } else {
+        workdayBg = mMonthView->preferences()->monthGridWorkHoursBackgroundColor();
+        holidayBg = mMonthView->preferences()->monthGridBackgroundColor();
+    }
 
     for (QDate d = start; d <= end; d = d.addDays(1)) {
-        if (!mScene->mMonthCellMap.contains(d)) {
+        const MonthCell *const cell = mScene->mMonthCellMap.value(d);
+
+        if (!cell) {
             // This means drawBackground() is being called before reloadIncidences(). Can happen with some
             // themes. Bug  #190191
             return;
         }
 
-        MonthCell *cell = mScene->mMonthCellMap[ d ];
-
-        QColor color;
-        if (!mMonthView->preferences()->useSystemColor()) {
-            if (workDays.contains(d)) {
-                color = mMonthView->preferences()->monthGridWorkHoursBackgroundColor();
-            } else {
-                color = mMonthView->preferences()->monthGridBackgroundColor();
-            }
-        } else {
-            if (workDays.contains(d)) {
-                color = palette().color(QPalette::Base);
-            } else {
-                color = palette().color(QPalette::AlternateBase);
-            }
-        }
-        const bool usingDark = EventViews::isColorDark(color);
+        const QRect cellRect(mScene->cellHorizontalPos(cell), mScene->cellVerticalPos(cell), columnWidth, rowHeight);
         if (cell == mScene->selectedCell()) {
-            color = (usingDark) ? color.lighter(150) : color.darker(115);
+            selectedRect = cellRect;
         }
-        if (cell->date() == QDate::currentDate()) {
-            color = (usingDark) ? color.lighter(200) : color.darker(140);
+        if (cell->date() == todayDate) {
+            todayRect = cellRect;
         }
 
         // Draw cell
         p->setPen(mMonthView->preferences()->monthGridBackgroundColor().darker(150));
-        p->setBrush(color);
-        p->drawRect(QRect(mScene->cellHorizontalPos(cell), mScene->cellVerticalPos(cell),
-                          columnWidth, rowHeight));
-
+        p->setBrush(workDays.contains(d) ? workdayBg : holidayBg);
+        p->drawRect(cellRect);
         if (mMonthView->isBusyDay(d)) {
             QColor busyColor = mMonthView->preferences()->viewBgBusyColor();
             busyColor.setAlpha(EventViews::BUSY_BACKGROUND_ALPHA);
             p->setBrush(busyColor);
-            p->drawRect(QRect(mScene->cellHorizontalPos(cell), mScene->cellVerticalPos(cell),
-                              columnWidth, rowHeight));
+            p->drawRect(cellRect);
         }
+    }
+    if (!todayRect.isNull()) {
+        KColorScheme scheme(QPalette::Normal, KColorScheme::ColorSet::View);
+        p->setPen(scheme.foreground(KColorScheme::ForegroundRole::PositiveText).color());
+        p->setBrush(scheme.background(KColorScheme::BackgroundRole::PositiveBackground));
+        p->drawRect(todayRect);
+    }
+    if (!selectedRect.isNull()) {
+        const KColorScheme scheme(QPalette::Normal, KColorScheme::ColorSet::Selection);
+        auto color = scheme.background(KColorScheme::BackgroundRole::NormalBackground).color();
+        p->setPen(color);
+        color.setAlpha(EventViews::BUSY_BACKGROUND_ALPHA);
+        p->setBrush(color);
+        p->drawRect(selectedRect);
+    }
+
+    /*
+     * Draw Dates
+     */
+
+    font = mMonthView->preferences()->monthViewFont();
+    font.setPixelSize(MonthCell::topMargin() - 4);
+    p->setFont(font);
+
+    QPen oldPen;
+    if (mMonthView->preferences()->useSystemColor()) {
+        oldPen = palette().color(QPalette::WindowText).darker(150);
+    } else {
+        oldPen = mMonthView->preferences()->monthGridBackgroundColor().darker(150);
+    }
+
+    for (QDate d = mMonthView->actualStartDateTime().date(); d <= mMonthView->actualEndDateTime().date(); d = d.addDays(1)) {
+        MonthCell *const cell = mScene->mMonthCellMap.value(d);
 
         // Draw cell header
         int cellHeaderX = mScene->cellHorizontalPos(cell) + 1;
         int cellHeaderY = mScene->cellVerticalPos(cell) + 1;
         int cellHeaderWidth = columnWidth - 2;
         int cellHeaderHeight = cell->topMargin() - 2;
-        QLinearGradient bgGradient(QPointF(cellHeaderX, cellHeaderY),
-                                   QPointF(cellHeaderX + cellHeaderWidth,
-                                           cellHeaderY + cellHeaderHeight));
-        // Compute color of grid lines based on dark/lightness
-        if (!usingDark) {
-            p->setBrush(color.darker(110));
-        } else {
-            p->setBrush(color.lighter(140));
-        }
-
-        bgGradient.setColorAt(1, color);
-
+        const auto brush = KColorScheme(QPalette::Normal, KColorScheme::ColorSet::Header).background(KColorScheme::BackgroundRole::NormalBackground);
+        p->setBrush(brush);
         p->setPen(Qt::NoPen);
-        p->drawRect(QRect(cellHeaderX, cellHeaderY,
-                          cellHeaderWidth, cellHeaderHeight));
-    }
-
-    font = mMonthView->preferences()->monthViewFont();
-    font.setPixelSize(MonthCell::topMargin() - 4);
-
-    p->setFont(font);
-
-    QPen oldPen;
-    if (!mMonthView->preferences()->useSystemColor()) {
-        oldPen = mMonthView->preferences()->monthGridBackgroundColor().darker(150);
-    } else {
-        oldPen = palette().color(QPalette::WindowText).darker(150);
-    }
-
-    // Draw dates
-    for (QDate d = mMonthView->actualStartDateTime().date();
-         d <= mMonthView->actualEndDateTime().date(); d = d.addDays(1)) {
-        MonthCell *cell = mScene->mMonthCellMap.value(d);
+        p->drawRect(QRect(cellHeaderX, cellHeaderY, cellHeaderWidth, cellHeaderHeight));
 
         QFont font = p->font();
-        if (cell->date() == QDate::currentDate()) {
-            font.setBold(true);
-        } else {
-            font.setBold(false);
-        }
+        font.setBold(cell->date() == todayDate);
         p->setFont(font);
 
         if (d.month() == mMonthView->currentMonth()) {
@@ -333,15 +308,29 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
             p->setPen(oldPen);
         }
 
+        QString dayText;
+        // Prepend month name if d is the first or last day of month
+        if (d.day() == 1 || // d is the first day of month
+            d.addDays(1).day() == 1) { // d is the last day of month
+            dayText = i18nc("'Month day' for month view cells", "%1 %2", QLocale::system().monthName(d.month(), QLocale::ShortFormat), d.day());
+        } else {
+            dayText = QString::number(d.day());
+        }
+        p->drawText(QRect(mScene->cellHorizontalPos(cell), // top right
+                          mScene->cellVerticalPos(cell), // of the cell
+                          mScene->columnWidth() - 2,
+                          cell->topMargin()),
+                    Qt::AlignRight,
+                    dayText);
+
         /*
           Draw arrows if all items won't fit
         */
 
         // Up arrow if first item is above cell top
         if (mScene->startHeight() != 0 && cell->hasEventBelow(mScene->startHeight())) {
-            cell->upArrow()->setPos(
-                mScene->cellHorizontalPos(cell) + columnWidth / 2,
-                mScene->cellVerticalPos(cell) + cell->upArrow()->boundingRect().height() / 2 + 2);
+            cell->upArrow()->setPos(mScene->cellHorizontalPos(cell) + columnWidth / 2,
+                                    mScene->cellVerticalPos(cell) + cell->upArrow()->boundingRect().height() / 2 + 2);
             cell->upArrow()->show();
         } else {
             cell->upArrow()->hide();
@@ -349,35 +338,13 @@ void MonthGraphicsView::drawBackground(QPainter *p, const QRectF &rect)
 
         // Down arrow if last item is below cell bottom
         if (!mScene->lastItemFit(cell)) {
-            cell->downArrow()->setPos(
-                mScene->cellHorizontalPos(cell) + columnWidth / 2,
-                mScene->cellVerticalPos(cell) + rowHeight
-                -cell->downArrow()->boundingRect().height() / 2 - 2);
+            cell->downArrow()->setPos(mScene->cellHorizontalPos(cell) + columnWidth / 2,
+                                      mScene->cellVerticalPos(cell) + rowHeight - cell->downArrow()->boundingRect().height() / 2 - 2);
             cell->downArrow()->show();
         } else {
             cell->downArrow()->hide();
         }
-
-        QString dayText;
-        // Prepend month name if d is the first or last day of month
-        if (d.day() == 1 ||             // d is the first day of month
-            d.addDays(1).day() == 1) {  // d is the last day of month
-            dayText = i18nc("'Month day' for month view cells", "%1 %2",
-                            QLocale::system().monthName(d.month(), QLocale::ShortFormat),
-                            d.day());
-        } else {
-            dayText = QString::number(d.day());
-        }
-
-        p->drawText(QRect(mScene->cellHorizontalPos(cell),     // top right
-                          mScene->cellVerticalPos(cell),       // of the cell
-                          mScene->columnWidth() - 2,
-                          cell->topMargin()),
-                    Qt::AlignRight,
-                    dayText);
     }
-
-    // ...
 }
 
 void MonthScene::resetAll()
@@ -415,9 +382,8 @@ bool MonthScene::lastItemFit(MonthCell *cell)
 int MonthScene::totalHeight()
 {
     int max = 0;
-    for (QDate d = mMonthView->actualStartDateTime().date();
-         d <= mMonthView->actualEndDateTime().date(); d = d.addDays(1)) {
-        int c = mMonthCellMap[ d ]->firstFreeSpace();
+    for (QDate d = mMonthView->actualStartDateTime().date(); d <= mMonthView->actualEndDateTime().date(); d = d.addDays(1)) {
+        int c = mMonthCellMap[d]->firstFreeSpace();
         if (c > max) {
             max = c;
         }
@@ -428,7 +394,7 @@ int MonthScene::totalHeight()
 
 void MonthScene::wheelEvent(QGraphicsSceneWheelEvent *event)
 {
-    Q_UNUSED(event);   // until we figure out what to do in here
+    Q_UNUSED(event) // until we figure out what to do in here
 
     /*  int numDegrees = -event->delta() / 8;
       int numSteps = numDegrees / 15;
@@ -477,7 +443,7 @@ void MonthScene::scrollCellsDown()
     int newHeight = startHeight() + 1;
     setStartHeight(newHeight);
 
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -489,7 +455,7 @@ void MonthScene::scrollCellsUp()
     int newHeight = startHeight() - 1;
     setStartHeight(newHeight);
 
-    for (MonthItem *manager : qAsConst(mManagerList)) {
+    for (MonthItem *manager : std::as_const(mManagerList)) {
         manager->updateGeometry();
     }
 
@@ -512,7 +478,7 @@ void MonthScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *mouseEvent)
     MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
     if (iItem) {
         if (iItem->monthItem()) {
-            IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(iItem->monthItem());
+            auto tmp = qobject_cast<IncidenceMonthItem *>(iItem->monthItem());
             if (tmp) {
                 selectItem(iItem->monthItem());
                 mMonthView->defaultAction(tmp->akonadiItem());
@@ -536,12 +502,9 @@ void MonthScene::mouseMoveEvent(QGraphicsSceneMouseEvent *mouseEvent)
     if (mActionType == None) {
         MonthGraphicsItem *iItem = dynamic_cast<MonthGraphicsItem *>(itemAt(pos, {}));
         if (iItem) {
-            if (iItem->monthItem()->isResizable() &&
-                iItem->isBeginItem() && iItem->mapFromScene(pos).x() <= 10) {
+            if (iItem->monthItem()->isResizable() && iItem->isBeginItem() && iItem->mapFromScene(pos).x() <= 10) {
                 view->setActionCursor(Resize);
-            } else if (iItem->monthItem()->isResizable() &&
-                       iItem->isEndItem() &&
-                       iItem->mapFromScene(pos).x() >= iItem->boundingRect().width() - 10) {
+            } else if (iItem->monthItem()->isResizable() && iItem->isEndItem() && iItem->mapFromScene(pos).x() >= iItem->boundingRect().width() - 10) {
                 view->setActionCursor(Resize);
             } else {
                 view->setActionCursor(None);
@@ -600,7 +563,7 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
         selectItem(mClickedItem);
         if (mouseEvent->button() == Qt::RightButton) {
-            IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(mClickedItem);
+            auto tmp = qobject_cast<IncidenceMonthItem *>(mClickedItem);
             if (tmp) {
                 Q_EMIT showIncidencePopupSignal(tmp->akonadiItem(), tmp->realStartDate());
             }
@@ -614,13 +577,10 @@ void MonthScene::mousePressEvent(QGraphicsSceneMouseEvent *mouseEvent)
             mActionInitiated = false;
 
             // Move or resize ?
-            if (iItem->monthItem()->isResizable() &&
-                iItem->isBeginItem() && iItem->mapFromScene(pos).x() <= 10) {
+            if (iItem->monthItem()->isResizable() && iItem->isBeginItem() && iItem->mapFromScene(pos).x() <= 10) {
                 mActionType = Resize;
                 mResizeType = ResizeLeft;
-            } else if (iItem->monthItem()->isResizable() &&
-                       iItem->isEndItem() &&
-                       iItem->mapFromScene(pos).x() >= iItem->boundingRect().width() - 10) {
+            } else if (iItem->monthItem()->isResizable() && iItem->isEndItem() && iItem->mapFromScene(pos).x() >= iItem->boundingRect().width() - 10) {
                 mActionType = Resize;
                 mResizeType = ResizeRight;
             } else if (iItem->monthItem()->isMoveable()) {
@@ -692,7 +652,7 @@ void MonthScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *mouseEvent)
 
         const bool somethingChanged = currentCell && currentCell != mStartCell;
 
-        if (somethingChanged) {   // We want to act if a move really happened
+        if (somethingChanged) { // We want to act if a move really happened
             if (mActionType == Resize) {
                 mActionItem->endResize();
             } else if (mActionType == Move) {
@@ -717,7 +677,7 @@ bool MonthScene::isInMonthGrid(int x, int y) const
 
 // The function converts the coordinates to the month grid coordinates to
 // be able to locate the cell.
-MonthCell *MonthScene::getCellFromPos(const QPointF &pos)
+MonthCell *MonthScene::getCellFromPos(QPointF pos)
 {
     int y = sceneYToMonthGridY(static_cast<int>(pos.y()));
     int x = sceneXToMonthGridX(static_cast<int>(pos.x()));
@@ -737,11 +697,11 @@ void MonthScene::selectItem(MonthItem *item)
       }
 
       I commented the above code so it's possible to selected a selected item.
-      korg-mobile needs that, otherwise clicking on a selected item wont bring the editor up.
+      korg-mobile needs that, otherwise clicking on a selected item won't bring the editor up.
       Another solution would be to have two Q_SIGNALS: incidenceSelected() and incidenceClicked()
     */
 
-    IncidenceMonthItem *tmp = qobject_cast<IncidenceMonthItem *>(item);
+    auto tmp = qobject_cast<IncidenceMonthItem *>(item);
 
     if (!tmp) {
         mSelectedItem = nullptr;
@@ -762,8 +722,8 @@ void MonthScene::selectItem(MonthItem *item)
 
 void MonthScene::removeIncidence(const QString &uid)
 {
-    for (MonthItem *manager : qAsConst(mManagerList)) {
-        IncidenceMonthItem *imi = qobject_cast<IncidenceMonthItem *>(manager);
+    for (MonthItem *manager : std::as_const(mManagerList)) {
+        auto imi = qobject_cast<IncidenceMonthItem *>(manager);
         if (!imi) {
             continue;
         }
