@@ -1,30 +1,13 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef EVENTVIEWS_MONTHSCENE_H
-#define EVENTVIEWS_MONTHSCENE_H
+#pragma once
 
-#include <Collection>
-#include <Item>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
 
 #include <QBasicTimer>
 #include <QDate>
@@ -32,11 +15,13 @@
 #include <QGraphicsView>
 #include <QMap>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class IncidenceChanger;
 }
 
-namespace EventViews {
+namespace EventViews
+{
 class MonthCell;
 class MonthItem;
 class MonthView;
@@ -46,17 +31,10 @@ class MonthScene : public QGraphicsScene
 {
     Q_OBJECT
 
-    enum ActionType {
-        None,
-        Move,
-        Resize
-    };
+    enum ActionType { None, Move, Resize };
 
 public:
-    enum ResizeType {
-        ResizeLeft,
-        ResizeRight
-    };
+    enum ResizeType { ResizeLeft, ResizeRight };
 
     explicit MonthScene(MonthView *parent);
     ~MonthScene() override;
@@ -118,12 +96,12 @@ public:
     /**
       Get the space on the right of the cell associated to the date @p date.
     */
-    Q_REQUIRED_RESULT int getRightSpan(const QDate &date) const;
+    Q_REQUIRED_RESULT int getRightSpan(QDate date) const;
 
     /**
       Get the space on the left of the cell associated to the date @p date.
     */
-    Q_REQUIRED_RESULT int getLeftSpan(const QDate &date) const;
+    Q_REQUIRED_RESULT int getLeftSpan(QDate date) const;
 
     /**
       Returns the date in the first column of the row given by @p row.
@@ -244,7 +222,7 @@ protected:
     /**
       Handles drag and drop events. Called from eventFilter.
     */
-//    virtual bool eventFilter_drag( QObject *, QDropEvent * );
+    //    virtual bool eventFilter_drag( QObject *, QDropEvent * );
 
     /**
       Returns true if the last item is visible in the given @p cell.
@@ -280,7 +258,7 @@ private:
      * Given a pos in the scene coordinates,
      * returns the cell containing @p pos.
      */
-    MonthCell *getCellFromPos(const QPointF &pos);
+    MonthCell *getCellFromPos(QPointF pos);
 
     /**
        Returns true if (x, y) is in the monthgrid, false else.
@@ -353,4 +331,3 @@ private:
 };
 }
 
-#endif
