@@ -1,33 +1,21 @@
 /*
-  Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Sergio Martins <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio.martins@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "multiagendaview.h"
 
-#include "prefs.h"
 #include "agenda/agenda.h"
 #include "agenda/agendaview.h"
 #include "agenda/timelabelszone.h"
-#include "configdialoginterface.h"
 #include "calendarview_debug.h"
+#include "configdialoginterface.h"
+#include "prefs.h"
 
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiWidgets/ETMViewStateSaver>
+#include <Akonadi/ETMViewStateSaver>
+#include <Akonadi/EntityTreeModel>
 
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
@@ -89,13 +77,14 @@ static QString generateColumnLabel(int c)
     return i18n("Agenda %1", c + 1);
 }
 
-class Q_DECL_HIDDEN MultiAgendaView::Private
+class EventViews::MultiAgendaViewPrivate
 {
 private:
     class ElidedLabel : public QFrame
     {
     public:
-        ElidedLabel(const QString &text) : mText(text)
+        ElidedLabel(const QString &text)
+            : mText(text)
         {
         }
 
@@ -105,20 +94,16 @@ private:
         void paintEvent(QPaintEvent *event) override;
 
     private:
-        QString mText;
+        const QString mText;
     };
 
 public:
-    Private(MultiAgendaView *qq)
+    explicit MultiAgendaViewPrivate(MultiAgendaView *qq)
         : q(qq)
-        , mUpdateOnShow(true)
-        , mPendingChanges(true)
-        , mCustomColumnSetupUsed(false)
-        , mCustomNumberOfColumns(2)
     {
     }
 
-    ~Private()
+    ~MultiAgendaViewPrivate()
     {
         qDeleteAll(mSelectionSavers);
     }
@@ -128,9 +113,9 @@ public:
     AgendaView *createView(const QString &title);
     void deleteViews();
     void setupViews();
-    void resizeScrollView(const QSize &size);
+    void resizeScrollView(QSize size);
 
-    MultiAgendaView *q;
+    MultiAgendaView *const q;
     QList<AgendaView *> mAgendaViews;
     QList<QWidget *> mAgendaWidgets;
     QWidget *mTopBox = nullptr;
@@ -142,33 +127,33 @@ public:
     QWidget *mLeftBottomSpacer = nullptr;
     QWidget *mRightBottomSpacer = nullptr;
     QDate mStartDate, mEndDate;
-    bool mUpdateOnShow;
-    bool mPendingChanges;
-    bool mCustomColumnSetupUsed;
+    bool mUpdateOnShow = true;
+    bool mPendingChanges = true;
+    bool mCustomColumnSetupUsed = false;
     QVector<KCheckableProxyModel *> mCollectionSelectionModels;
     QStringList mCustomColumnTitles;
-    int mCustomNumberOfColumns;
+    int mCustomNumberOfColumns = 2;
     QLabel *mLabel = nullptr;
     QWidget *mRightDummyWidget = nullptr;
-    QHash<QString, KViewStateMaintainer<ETMViewStateSaver> * > mSelectionSavers;
+    QHash<QString, KViewStateMaintainer<ETMViewStateSaver> *> mSelectionSavers;
 };
 
 MultiAgendaView::MultiAgendaView(QWidget *parent)
     : EventView(parent)
-    , d(new Private(this))
+    , d(new MultiAgendaViewPrivate(this))
 {
-    QHBoxLayout *topLevelLayout = new QHBoxLayout(this);
+    auto topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
     topLevelLayout->setContentsMargins(0, 0, 0, 0);
 
     QFontMetrics fm(font());
     int topLabelHeight = 2 * fm.height() + fm.lineSpacing();
 
-    QWidget *topSideBox = new QWidget(this);
-    QVBoxLayout *topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
+    auto topSideBox = new QWidget(this);
+    auto topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
     topSideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
-    QWidget *topSideSpacer = new QWidget(topSideBox);
+    auto topSideSpacer = new QWidget(topSideBox);
     topSideBoxVBoxLayout->addWidget(topSideSpacer);
     topSideSpacer->setFixedHeight(topLabelHeight);
 
@@ -179,17 +164,17 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
     d->mLabel->setWordWrap(true);
 
-    QWidget *sideBox = new QWidget(d->mLeftSplitter);
-    QVBoxLayout *sideBoxVBoxLayout = new QVBoxLayout(sideBox);
+    auto sideBox = new QWidget(d->mLeftSplitter);
+    auto sideBoxVBoxLayout = new QVBoxLayout(sideBox);
     sideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     // compensate for the frame the agenda views but not the timelabels have
-    QWidget *timeLabelTopAlignmentSpacer = new QWidget(sideBox);
+    auto timeLabelTopAlignmentSpacer = new QWidget(sideBox);
     sideBoxVBoxLayout->addWidget(timeLabelTopAlignmentSpacer);
 
     d->mTimeLabelsZone = new TimeLabelsZone(sideBox, PrefsPtr(new Prefs()));
 
-    QWidget *timeLabelBotAlignmentSpacer = new QWidget(sideBox);
+    auto timeLabelBotAlignmentSpacer = new QWidget(sideBox);
     sideBoxVBoxLayout->addWidget(timeLabelBotAlignmentSpacer);
 
     d->mLeftBottomSpacer = new QWidget(topSideBox);
@@ -203,7 +188,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     // BUG: timelabels aren't aligned with the agenda's grid, 2 or 3 pixels of offset.
-    // asymetric since the timelabels
+    // asymmetric since the timelabels
     timeLabelTopAlignmentSpacer->setFixedHeight(d->mScrollArea->frameWidth() - 1);
     // have 25 horizontal lines
     timeLabelBotAlignmentSpacer->setFixedHeight(d->mScrollArea->frameWidth() - 2);
@@ -211,7 +196,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mScrollArea->setFrameShape(QFrame::NoFrame);
     topLevelLayout->addWidget(d->mScrollArea, 100);
     d->mTopBox = new QWidget(d->mScrollArea->viewport());
-    QHBoxLayout *mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
+    auto mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
     mTopBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mScrollArea->setWidget(d->mTopBox);
 
@@ -241,16 +226,13 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
 void MultiAgendaView::setCalendar(const Akonadi::ETMCalendar::Ptr &calendar)
 {
     EventView::setCalendar(calendar);
-    for (KCheckableProxyModel *proxy : qAsConst(d->mCollectionSelectionModels)) {
+    for (KCheckableProxyModel *proxy : std::as_const(d->mCollectionSelectionModels)) {
         proxy->setSourceModel(calendar->entityTreeModel());
     }
 
-    disconnect(nullptr,
-               SIGNAL(selectionChanged(Akonadi::Collection::List,Akonadi::Collection::List)),
-               this, SLOT(forceRecreateViews()));
+    disconnect(nullptr, SIGNAL(selectionChanged(Akonadi::Collection::List, Akonadi::Collection::List)), this, SLOT(forceRecreateViews()));
 
-    connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged,
-            this, &MultiAgendaView::forceRecreateViews);
+    connect(collectionSelection(), &CalendarSupport::CollectionSelection::selectionChanged, this, &MultiAgendaView::forceRecreateViews);
 
     recreateViews();
 }
@@ -288,10 +270,8 @@ void MultiAgendaView::recreateViews()
     d->mTimeLabelsZone->updateAll();
 
     QScrollArea *timeLabel = d->mTimeLabelsZone->timeLabels().at(0);
-    connect(timeLabel->verticalScrollBar(), &QAbstractSlider::valueChanged,
-            d->mScrollBar, &QAbstractSlider::setValue);
-    connect(d->mScrollBar, &QAbstractSlider::valueChanged,
-            timeLabel->verticalScrollBar(), &QAbstractSlider::setValue);
+    connect(timeLabel->verticalScrollBar(), &QAbstractSlider::valueChanged, d->mScrollBar, &QAbstractSlider::setValue);
+    connect(d->mScrollBar, &QAbstractSlider::valueChanged, timeLabel->verticalScrollBar(), &QAbstractSlider::setValue);
 
     resizeSplitters();
     QTimer::singleShot(0, this, &MultiAgendaView::setupScrollBar);
@@ -305,9 +285,9 @@ void MultiAgendaView::forceRecreateViews()
     recreateViews();
 }
 
-void MultiAgendaView::Private::deleteViews()
+void MultiAgendaViewPrivate::deleteViews()
 {
-    for (AgendaView *const i : qAsConst(mAgendaViews)) {
+    for (AgendaView *const i : std::as_const(mAgendaViews)) {
         KCheckableProxyModel *proxy = i->takeCustomCollectionSelectionProxyModel();
         if (proxy && !mCollectionSelectionModels.contains(proxy)) {
             delete proxy;
@@ -321,79 +301,57 @@ void MultiAgendaView::Private::deleteViews()
     mAgendaWidgets.clear();
 }
 
-void MultiAgendaView::Private::setupViews()
+void MultiAgendaViewPrivate::setupViews()
 {
-    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
-        q->connect(agenda, SIGNAL(newEventSignal()),
-                   q, SIGNAL(newEventSignal()));
-        q->connect(agenda, SIGNAL(newEventSignal(QDate)),
-                   q, SIGNAL(newEventSignal(QDate)));
-        q->connect(agenda, SIGNAL(newEventSignal(QDateTime)),
-                   q, SIGNAL(newEventSignal(QDateTime)));
-        q->connect(agenda,
-                   SIGNAL(newEventSignal(QDateTime,QDateTime)),
-                   q, SIGNAL(newEventSignal(QDateTime,QDateTime)));
+    for (AgendaView *agenda : std::as_const(mAgendaViews)) {
+        q->connect(agenda, SIGNAL(newEventSignal()), q, SIGNAL(newEventSignal()));
+        q->connect(agenda, SIGNAL(newEventSignal(QDate)), q, SIGNAL(newEventSignal(QDate)));
+        q->connect(agenda, SIGNAL(newEventSignal(QDateTime)), q, SIGNAL(newEventSignal(QDateTime)));
+        q->connect(agenda, SIGNAL(newEventSignal(QDateTime, QDateTime)), q, SIGNAL(newEventSignal(QDateTime, QDateTime)));
 
-        q->connect(agenda, &EventView::editIncidenceSignal,
-                   q, &EventView::editIncidenceSignal);
-        q->connect(agenda, &EventView::showIncidenceSignal,
-                   q, &EventView::showIncidenceSignal);
-        q->connect(agenda, &EventView::deleteIncidenceSignal,
-                   q, &EventView::deleteIncidenceSignal);
+        q->connect(agenda, &EventView::editIncidenceSignal, q, &EventView::editIncidenceSignal);
+        q->connect(agenda, &EventView::showIncidenceSignal, q, &EventView::showIncidenceSignal);
+        q->connect(agenda, &EventView::deleteIncidenceSignal, q, &EventView::deleteIncidenceSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected,
-                   q, &EventView::incidenceSelected);
+        q->connect(agenda, &EventView::incidenceSelected, q, &EventView::incidenceSelected);
 
-        q->connect(agenda, &EventView::cutIncidenceSignal,
-                   q, &EventView::cutIncidenceSignal);
-        q->connect(agenda, &EventView::copyIncidenceSignal,
-                   q, &EventView::copyIncidenceSignal);
-        q->connect(agenda, &EventView::pasteIncidenceSignal,
-                   q, &EventView::pasteIncidenceSignal);
-        q->connect(agenda, &EventView::toggleAlarmSignal,
-                   q, &EventView::toggleAlarmSignal);
-        q->connect(agenda, &EventView::dissociateOccurrencesSignal,
-                   q, &EventView::dissociateOccurrencesSignal);
+        q->connect(agenda, &EventView::cutIncidenceSignal, q, &EventView::cutIncidenceSignal);
+        q->connect(agenda, &EventView::copyIncidenceSignal, q, &EventView::copyIncidenceSignal);
+        q->connect(agenda, &EventView::pasteIncidenceSignal, q, &EventView::pasteIncidenceSignal);
+        q->connect(agenda, &EventView::toggleAlarmSignal, q, &EventView::toggleAlarmSignal);
+        q->connect(agenda, &EventView::dissociateOccurrencesSignal, q, &EventView::dissociateOccurrencesSignal);
 
-        q->connect(agenda, &EventView::newTodoSignal,
-                   q, &EventView::newTodoSignal);
+        q->connect(agenda, &EventView::newTodoSignal, q, &EventView::newTodoSignal);
 
-        q->connect(agenda, &EventView::incidenceSelected,
-                   q, &MultiAgendaView::slotSelectionChanged);
+        q->connect(agenda, &EventView::incidenceSelected, q, &MultiAgendaView::slotSelectionChanged);
 
-        q->connect(agenda, &AgendaView::timeSpanSelectionChanged,
-                   q, &MultiAgendaView::slotClearTimeSpanSelection);
+        q->connect(agenda, &AgendaView::timeSpanSelectionChanged, q, &MultiAgendaView::slotClearTimeSpanSelection);
 
-        q->disconnect(agenda->agenda(),
-                      SIGNAL(zoomView(int,QPoint,Qt::Orientation)),
-                      agenda, nullptr);
-        q->connect(agenda->agenda(),
-                   &Agenda::zoomView,
-                   q, &MultiAgendaView::zoomView);
+        q->disconnect(agenda->agenda(), SIGNAL(zoomView(int, QPoint, Qt::Orientation)), agenda, nullptr);
+        q->connect(agenda->agenda(), &Agenda::zoomView, q, &MultiAgendaView::zoomView);
     }
 
     AgendaView *lastView = mAgendaViews.last();
-    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(mAgendaViews)) {
         if (agenda != lastView) {
-            connect(agenda->agenda()->verticalScrollBar(), &QAbstractSlider::valueChanged,
-                    lastView->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
+            q->connect(agenda->agenda()->verticalScrollBar(),
+                       &QAbstractSlider::valueChanged,
+                       lastView->agenda()->verticalScrollBar(),
+                       &QAbstractSlider::setValue);
         }
     }
 
-    for (AgendaView *agenda : qAsConst(mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(mAgendaViews)) {
         agenda->readSettings();
     }
 }
 
-MultiAgendaView::~MultiAgendaView()
-{
-    delete d;
-}
+MultiAgendaView::~MultiAgendaView() = default;
 
 Akonadi::Item::List MultiAgendaView::selectedIncidences() const
 {
     Akonadi::Item::List list;
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         list += agendaView->selectedIncidences();
     }
     return list;
@@ -402,7 +360,7 @@ Akonadi::Item::List MultiAgendaView::selectedIncidences() const
 KCalendarCore::DateList MultiAgendaView::selectedIncidenceDates() const
 {
     KCalendarCore::DateList list;
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         list += agendaView->selectedIncidenceDates();
     }
     return list;
@@ -410,7 +368,7 @@ KCalendarCore::DateList MultiAgendaView::selectedIncidenceDates() const
 
 int MultiAgendaView::currentDateCount() const
 {
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         return agendaView->currentDateCount();
     }
     return 0;
@@ -418,19 +376,19 @@ int MultiAgendaView::currentDateCount() const
 
 void MultiAgendaView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
-    Q_UNUSED(preferredMonth);
+    Q_UNUSED(preferredMonth)
     d->mStartDate = start;
     d->mEndDate = end;
     slotResizeScrollView();
     d->mTimeLabelsZone->updateAll();
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         agendaView->showDates(start, end);
     }
 }
 
 void MultiAgendaView::showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date)
 {
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         agendaView->showIncidences(incidenceList, date);
     }
 }
@@ -438,7 +396,7 @@ void MultiAgendaView::showIncidences(const Akonadi::Item::List &incidenceList, c
 void MultiAgendaView::updateView()
 {
     recreateViews();
-    for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agendaView : std::as_const(d->mAgendaViews)) {
         agendaView->updateView();
     }
 }
@@ -451,7 +409,7 @@ int MultiAgendaView::maxDatesHint() const
 
 void MultiAgendaView::slotSelectionChanged()
 {
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         if (agenda != sender()) {
             agenda->clearSelection();
         }
@@ -460,7 +418,7 @@ void MultiAgendaView::slotSelectionChanged()
 
 bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) const
 {
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         bool valid = agenda->eventDurationHint(startDt, endDt, allDay);
         if (valid) {
             return true;
@@ -471,7 +429,7 @@ bool MultiAgendaView::eventDurationHint(QDateTime &startDt, QDateTime &endDt, bo
 
 void MultiAgendaView::slotClearTimeSpanSelection()
 {
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         if (agenda != sender()) {
             agenda->clearTimeSpanSelection();
         } else {
@@ -480,18 +438,14 @@ void MultiAgendaView::slotClearTimeSpanSelection()
     }
 }
 
-AgendaView *MultiAgendaView::Private::createView(const QString &title)
+AgendaView *MultiAgendaViewPrivate::createView(const QString &title)
 {
-    QWidget *box = new QWidget(mTopBox);
+    auto box = new QWidget(mTopBox);
     mTopBox->layout()->addWidget(box);
-    QVBoxLayout *layout = new QVBoxLayout(box);
+    auto layout = new QVBoxLayout(box);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(new ElidedLabel(title));
-    AgendaView *av = new AgendaView(q->preferences(),
-                                    q->startDateTime().date(),
-                                    q->endDateTime().date(),
-                                    true,
-                                    true, q);
+    auto av = new AgendaView(q->preferences(), q->startDateTime().date(), q->endDateTime().date(), true, true, q);
     layout->addWidget(av);
     av->setCalendar(q->calendar());
     av->setIncidenceChanger(q->changer());
@@ -501,16 +455,12 @@ AgendaView *MultiAgendaView::Private::createView(const QString &title)
     box->show();
     mTimeLabelsZone->setAgendaView(av);
 
-    q->connect(mScrollBar, &QAbstractSlider::valueChanged,
-               av->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
+    q->connect(mScrollBar, &QAbstractSlider::valueChanged, av->agenda()->verticalScrollBar(), &QAbstractSlider::setValue);
 
-    q->connect(av->splitter(), &QSplitter::splitterMoved,
-               q, &MultiAgendaView::resizeSplitters);
-    q->connect(av, &AgendaView::showIncidencePopupSignal,
-               q, &MultiAgendaView::showIncidencePopupSignal);
+    q->connect(av->splitter(), &QSplitter::splitterMoved, q, &MultiAgendaView::resizeSplitters);
+    q->connect(av, &AgendaView::showIncidencePopupSignal, q, &MultiAgendaView::showIncidencePopupSignal);
 
-    q->connect(av, &AgendaView::showNewEventPopupSignal,
-               q, &MultiAgendaView::showNewEventPopupSignal);
+    q->connect(av, &AgendaView::showNewEventPopupSignal, q, &MultiAgendaView::showNewEventPopupSignal);
 
     const QSize minHint = av->allDayAgenda()->scrollArea()->minimumSizeHint();
 
@@ -522,13 +472,13 @@ AgendaView *MultiAgendaView::Private::createView(const QString &title)
     return av;
 }
 
-void MultiAgendaView::Private::addView(const Akonadi::Collection &collection)
+void MultiAgendaViewPrivate::addView(const Akonadi::Collection &collection)
 {
     AgendaView *av = createView(CalendarSupport::displayName(q->calendar().data(), collection));
     av->setCollectionId(collection.id());
 }
 
-void MultiAgendaView::Private::addView(KCheckableProxyModel *sm, const QString &title)
+void MultiAgendaViewPrivate::addView(KCheckableProxyModel *sm, const QString &title)
 {
     AgendaView *av = createView(title);
     av->setCustomCollectionSelectionProxyModel(sm);
@@ -540,7 +490,7 @@ void MultiAgendaView::resizeEvent(QResizeEvent *ev)
     EventView::resizeEvent(ev);
 }
 
-void MultiAgendaView::Private::resizeScrollView(const QSize &size)
+void MultiAgendaViewPrivate::resizeScrollView(QSize size)
 {
     const int widgetWidth = size.width() - mTimeLabelsZone->width() - mScrollBar->width();
 
@@ -561,14 +511,14 @@ void MultiAgendaView::Private::resizeScrollView(const QSize &size)
 void MultiAgendaView::setIncidenceChanger(Akonadi::IncidenceChanger *changer)
 {
     EventView::setIncidenceChanger(changer);
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         agenda->setIncidenceChanger(changer);
     }
 }
 
 void MultiAgendaView::setPreferences(const PrefsPtr &prefs)
 {
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         agenda->setPreferences(prefs);
     }
     EventView::setPreferences(prefs);
@@ -579,7 +529,7 @@ void MultiAgendaView::updateConfig()
     EventView::updateConfig();
     d->mTimeLabelsZone->setPreferences(preferences());
     d->mTimeLabelsZone->updateAll();
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         agenda->updateConfig();
     }
 }
@@ -590,11 +540,11 @@ void MultiAgendaView::resizeSplitters()
         return;
     }
 
-    QSplitter *lastMovedSplitter = qobject_cast<QSplitter *>(sender());
+    auto lastMovedSplitter = qobject_cast<QSplitter *>(sender());
     if (!lastMovedSplitter) {
         lastMovedSplitter = d->mLeftSplitter;
     }
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         if (agenda->splitter() == lastMovedSplitter) {
             continue;
         }
@@ -608,7 +558,7 @@ void MultiAgendaView::resizeSplitters()
     }
 }
 
-void MultiAgendaView::zoomView(const int delta, const QPoint &pos, const Qt::Orientation ori)
+void MultiAgendaView::zoomView(const int delta, QPoint pos, const Qt::Orientation ori)
 {
     const int hourSz = preferences()->hourSize();
     if (ori == Qt::Vertical) {
@@ -621,7 +571,7 @@ void MultiAgendaView::zoomView(const int delta, const QPoint &pos, const Qt::Ori
         }
     }
 
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         agenda->zoomView(delta, pos, ori);
     }
 
@@ -646,15 +596,15 @@ void MultiAgendaView::showEvent(QShowEvent *event)
 void MultiAgendaView::setChanges(Changes changes)
 {
     EventView::setChanges(changes);
-    for (AgendaView *agenda : qAsConst(d->mAgendaViews)) {
+    for (AgendaView *agenda : std::as_const(d->mAgendaViews)) {
         agenda->setChanges(changes);
     }
 }
 
 void MultiAgendaView::setupScrollBar()
 {
-    if (!d->mAgendaViews.isEmpty() && d->mAgendaViews.first()->agenda()) {
-        QScrollBar *scrollBar = d->mAgendaViews.first()->agenda()->verticalScrollBar();
+    if (!d->mAgendaViews.isEmpty() && d->mAgendaViews.constFirst()->agenda()) {
+        QScrollBar *scrollBar = d->mAgendaViews.constFirst()->agenda()->verticalScrollBar();
         d->mScrollBar->setMinimum(scrollBar->minimum());
         d->mScrollBar->setMaximum(scrollBar->maximum());
         d->mScrollBar->setSingleStep(scrollBar->singleStep());
@@ -704,31 +654,28 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
         d->mCollectionSelectionModels.resize(d->mCustomNumberOfColumns);
         for (int i = 0; i < d->mCustomNumberOfColumns; ++i) {
             // Sort the calanders by name
-            QSortFilterProxyModel *sortProxy = new QSortFilterProxyModel(this);
+            auto sortProxy = new QSortFilterProxyModel(this);
             sortProxy->setDynamicSortFilter(true);
 
             sortProxy->setSourceModel(calendar()->entityTreeModel());
 
             // Only show the first column
-            KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
-            columnFilterProxy->setSourceColumns(
-                QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
+            auto columnFilterProxy = new KRearrangeColumnsProxyModel(this);
+            columnFilterProxy->setSourceColumns(QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
             // Keep track of selection.
-            QItemSelectionModel *qsm = new QItemSelectionModel(columnFilterProxy);
+            auto qsm = new QItemSelectionModel(columnFilterProxy);
 
             // Make the model checkable.
-            KCheckableProxyModel *checkableProxy = new KCheckableProxyModel(this);
+            auto checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
-            const QString groupName
-                = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
+            const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(i);
             const KConfigGroup group = configGroup.config()->group(groupName);
 
             if (!d->mSelectionSavers.contains(groupName)) {
-                d->mSelectionSavers.insert(groupName,
-                                           new KViewStateMaintainer<ETMViewStateSaver>(group));
+                d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
                 d->mSelectionSavers[groupName]->setSelectionModel(checkableProxy->selectionModel());
             }
 
@@ -748,16 +695,14 @@ void MultiAgendaView::doSaveConfig(KConfigGroup &configGroup)
     configGroup.writeEntry("CustomNumberOfColumns", d->mCustomNumberOfColumns);
     configGroup.writeEntry("ColumnTitles", d->mCustomColumnTitles);
     int idx = 0;
-    for (KCheckableProxyModel *checkableProxyModel : qAsConst(d->mCollectionSelectionModels)) {
-        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(
-            idx);
+    for (KCheckableProxyModel *checkableProxyModel : std::as_const(d->mCollectionSelectionModels)) {
+        const QString groupName = configGroup.name() + QLatin1String("_subView_") + QString::number(idx);
         KConfigGroup group = configGroup.config()->group(groupName);
         ++idx;
-        //TODO never used ?
+        // TODO never used ?
         KViewStateMaintainer<ETMViewStateSaver> saver(group);
         if (!d->mSelectionSavers.contains(groupName)) {
-            d->mSelectionSavers.insert(groupName,
-                                       new KViewStateMaintainer<ETMViewStateSaver>(group));
+            d->mSelectionSavers.insert(groupName, new KViewStateMaintainer<ETMViewStateSaver>(group));
             d->mSelectionSavers[groupName]->setSelectionModel(checkableProxyModel->selectionModel());
         }
         d->mSelectionSavers[groupName]->saveState();
@@ -806,7 +751,7 @@ QStringList MultiAgendaView::customColumnTitles() const
     return d->mCustomColumnTitles;
 }
 
-void MultiAgendaView::Private::ElidedLabel::paintEvent(QPaintEvent *event)
+void MultiAgendaViewPrivate::ElidedLabel::paintEvent(QPaintEvent *event)
 {
     QFrame::paintEvent(event);
     QPainter p(this);
@@ -815,7 +760,7 @@ void MultiAgendaView::Private::ElidedLabel::paintEvent(QPaintEvent *event)
     p.drawText(r, Qt::AlignHCenter | Qt::AlignVCenter, elidedText);
 }
 
-QSize MultiAgendaView::Private::ElidedLabel::minimumSizeHint() const
+QSize MultiAgendaViewPrivate::ElidedLabel::minimumSizeHint() const
 {
     const QFontMetrics &fm = fontMetrics();
     return QSize(fm.boundingRect(QStringLiteral("...")).width(), fm.height());
