@@ -1,61 +1,46 @@
 /*
-  Copyright (c) 2007 Till Adam <adam@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2007 Till Adam <adam@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "timelineview.h"
-#include "timelineview_p.h"
-#include "timelineitem.h"
 #include "helper.h"
+#include "timelineitem.h"
+#include "timelineview_p.h"
 
-#include <KGantt/KGanttGraphicsItem>
-#include <KGantt/KGanttGraphicsView>
 #include <KGantt/KGanttAbstractRowController>
 #include <KGantt/KGanttDateTimeGrid>
+#include <KGantt/KGanttGraphicsItem>
+#include <KGantt/KGanttGraphicsView>
 #include <KGantt/KGanttItemDelegate>
 #include <KGantt/KGanttStyleOptionGanttItem>
 
 #include <Akonadi/Calendar/ETMCalendar>
+#include <Akonadi/Calendar/IncidenceChanger>
 #include <CalendarSupport/CollectionSelection>
 #include <CalendarSupport/Utils>
-#include <Akonadi/Calendar/IncidenceChanger>
 
 #include "calendarview_debug.h"
 
-#include <QApplication>
-#include <QPainter>
-#include <QStandardItemModel>
-#include <QSplitter>
-#include <QTreeWidget>
-#include <QHeaderView>
-#include <QPointer>
-#include <QVBoxLayout>
-#include <QHelpEvent>
 #include <KLocalizedString>
+#include <QApplication>
+#include <QHeaderView>
+#include <QHelpEvent>
+#include <QPainter>
+#include <QPointer>
+#include <QSplitter>
+#include <QStandardItemModel>
+#include <QTreeWidget>
+#include <QVBoxLayout>
 
 using namespace KCalendarCore;
 using namespace EventViews;
 
-namespace EventViews {
+namespace EventViews
+{
 class RowController : public KGantt::AbstractRowController
 {
 private:
@@ -111,7 +96,7 @@ public:
     QModelIndex indexBelow(const QModelIndex &idx) const override
     {
         if (!idx.isValid()) {
-            return QModelIndex();
+            return {};
         }
         return idx.model()->index(idx.row() + 1, idx.column(), idx.parent());
     }
@@ -119,7 +104,7 @@ public:
     QModelIndex indexAbove(const QModelIndex &idx) const override
     {
         if (!idx.isValid()) {
-            return QModelIndex();
+            return {};
         }
         return idx.model()->index(idx.row() - 1, idx.column(), idx.parent());
     }
@@ -136,8 +121,10 @@ private:
 class GanttHeaderView : public QHeaderView
 {
 public:
-    explicit GanttHeaderView(QWidget *parent = nullptr) : QHeaderView(Qt::Horizontal, parent)
+    explicit GanttHeaderView(QWidget *parent = nullptr)
+        : QHeaderView(Qt::Horizontal, parent)
     {
+        setSectionResizeMode(QHeaderView::Stretch);
     }
 
     QSize sizeHint() const override
@@ -154,6 +141,7 @@ public:
         : KGantt::ItemDelegate(parent)
     {
     }
+
 private:
     void paintGanttItem(QPainter *painter, const KGantt::StyleOptionGanttItem &opt, const QModelIndex &idx) override
     {
@@ -161,8 +149,7 @@ private:
         if (!idx.isValid()) {
             return;
         }
-        const KGantt::ItemType type = static_cast<KGantt::ItemType>(
-            idx.model()->data(idx, KGantt::ItemTypeRole).toInt());
+        const KGantt::ItemType type = static_cast<KGantt::ItemType>(idx.model()->data(idx, KGantt::ItemTypeRole).toInt());
 
         const QString txt = idx.model()->data(idx, Qt::DisplayRole).toString();
         QRectF itemRect = opt.itemRect;
@@ -172,8 +159,7 @@ private:
 
         QBrush brush = defaultBrush(type);
         if (opt.state & QStyle::State_Selected) {
-            QLinearGradient selectedGrad(0., 0., 0.,
-                                         QApplication::fontMetrics().height());
+            QLinearGradient selectedGrad(0., 0., 0., QApplication::fontMetrics().height());
             selectedGrad.setColorAt(0., Qt::red);
             selectedGrad.setColorAt(1., Qt::darkRed);
 
@@ -220,13 +206,20 @@ private:
 };
 }
 
+TimelineView::TimelineView(const EventViews::PrefsPtr &preferences, QWidget *parent)
+    : TimelineView(parent)
+{
+    setPreferences(preferences);
+}
+
 TimelineView::TimelineView(QWidget *parent)
     : EventView(parent)
-    , d(new Private(this))
+    , d(new TimelineViewPrivate(this))
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
-    QSplitter *splitter = new QSplitter(Qt::Horizontal, this);
+    auto vbox = new QVBoxLayout(this);
+    auto splitter = new QSplitter(Qt::Horizontal, this);
     d->mLeftView = new QTreeWidget;
+    d->mLeftView->setColumnCount(1);
     d->mLeftView->setHeader(new GanttHeaderView);
     d->mLeftView->setHeaderLabel(i18n("Calendar"));
     d->mLeftView->setRootIsDecorated(false);
@@ -236,21 +229,19 @@ TimelineView::TimelineView(QWidget *parent)
     d->mGantt = new KGantt::GraphicsView(this);
     splitter->addWidget(d->mLeftView);
     splitter->addWidget(d->mGantt);
-    connect(splitter, &QSplitter::splitterMoved,
-            d, &Private::splitterMoved);
-    QStandardItemModel *model = new QStandardItemModel(this);
+    splitter->setSizes({200, 600});
+    auto model = new QStandardItemModel(this);
 
     d->mRowController = new RowController;
 
     QStyleOptionViewItem opt;
     opt.initFrom(d->mLeftView);
-    const auto h = d->mLeftView->style()->sizeFromContents(QStyle::CT_ItemViewItem, &opt,
-                                                           QSize(), d->mLeftView).height();
+    const auto h = d->mLeftView->style()->sizeFromContents(QStyle::CT_ItemViewItem, &opt, QSize(), d->mLeftView).height();
     d->mRowController->setRowHeight(h);
 
     d->mRowController->setModel(model);
     d->mGantt->setRowController(d->mRowController);
-    KGantt::DateTimeGrid *grid = new KGantt::DateTimeGrid();
+    auto grid = new KGantt::DateTimeGrid();
     grid->setScale(KGantt::DateTimeGrid::ScaleHour);
     grid->setDayWidth(800);
     grid->setRowSeparators(true);
@@ -263,20 +254,16 @@ TimelineView::TimelineView(QWidget *parent)
 
     vbox->addWidget(splitter);
 
-    connect(model, &QStandardItemModel::itemChanged,
-            d, &Private::itemChanged);
+    connect(model, &QStandardItemModel::itemChanged, d.get(), &TimelineViewPrivate::itemChanged);
 
-    connect(d->mGantt, &KGantt::GraphicsView::activated,
-            d, &Private::itemSelected);
+    connect(d->mGantt, &KGantt::GraphicsView::activated, d.get(), &TimelineViewPrivate::itemSelected);
     d->mGantt->setContextMenuPolicy(Qt::CustomContextMenu);
-    connect(d->mGantt, &QWidget::customContextMenuRequested,
-            d, &Private::contextMenuRequested);
+    connect(d->mGantt, &QWidget::customContextMenuRequested, d.get(), &TimelineViewPrivate::contextMenuRequested);
 }
 
 TimelineView::~TimelineView()
 {
     delete d->mRowController;
-    delete d;
 }
 
 Akonadi::Item::List TimelineView::selectedIncidences() const
@@ -296,7 +283,7 @@ int TimelineView::currentDateCount() const
 
 void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
 {
-    Q_UNUSED(preferredMonth);
+    Q_UNUSED(preferredMonth)
     Q_ASSERT_X(calendar(), "showDates()", "set a Akonadi::ETMCalendar");
     Q_ASSERT_X(start.isValid(), "showDates()", "start date must be valid");
     Q_ASSERT_X(end.isValid(), "showDates()", "end date must be valid");
@@ -307,22 +294,13 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
     d->mEndDate = end;
     d->mHintDate = QDateTime();
 
-    KGantt::DateTimeGrid *grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    grid->setStartDateTime(QDateTime(start));
-#else
+    auto grid = static_cast<KGantt::DateTimeGrid *>(d->mGantt->grid());
     grid->setStartDateTime(QDateTime(start.startOfDay()));
-#endif
     d->mLeftView->clear();
     uint index = 0;
-    // item for every calendar
-    TimelineItem *item = nullptr;
     Akonadi::ETMCalendar::Ptr calres = calendar();
     if (!calres) {
-        item = new TimelineItem(calendar(),
-                                index++,
-                                static_cast<QStandardItemModel *>(d->mGantt->model()),
-                                d->mGantt);
+        auto item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
         d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << i18n("Calendar")));
         d->mCalendarItemMap.insert(-1, item);
     } else {
@@ -331,23 +309,14 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
 
         for (const Akonadi::Collection &collection : collections) {
             if (collection.contentMimeTypes().contains(Event::eventMimeType())) {
-                item = new TimelineItem(calendar(),
-                                        index++,
-                                        static_cast<QStandardItemModel *>(d->mGantt->model()),
-                                        d->mGantt);
-                d->mLeftView->addTopLevelItem(
-                    new QTreeWidgetItem(
-                        QStringList() << CalendarSupport::displayName(
-                            calendar().data(), collection)));
+                auto item = new TimelineItem(calendar(), index++, static_cast<QStandardItemModel *>(d->mGantt->model()), d->mGantt);
+                d->mLeftView->addTopLevelItem(new QTreeWidgetItem(QStringList() << CalendarSupport::displayName(calendar().data(), collection)));
                 const QColor resourceColor = EventViews::resourceColor(collection, preferences());
                 if (resourceColor.isValid()) {
                     item->setColor(resourceColor);
                 }
-                qCDebug(CALENDARVIEW_LOG) << "Created item " << item
-                                          << " (" <<  CalendarSupport::displayName(
-                    calendar().data(), collection) << ") "
-                                          << "with index " <<  index - 1 << " from collection "
-                                          << collection.id();
+                qCDebug(CALENDARVIEW_LOG) << "Created item " << item << " (" << CalendarSupport::displayName(calendar().data(), collection) << ") "
+                                          << "with index " << index - 1 << " from collection " << collection.id();
                 d->mCalendarItemMap.insert(collection.id(), item);
             }
         }
@@ -365,10 +334,8 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
 
     KCalendarCore::Event::List events;
     for (QDate day = start; day <= end; day = day.addDays(1)) {
-        events = calendar()->events(day, QTimeZone::systemTimeZone(),
-                                    KCalendarCore::EventSortStartDate,
-                                    KCalendarCore::SortDirectionAscending);
-        for (const KCalendarCore::Event::Ptr &event : qAsConst(events)) {
+        events = calendar()->events(day, QTimeZone::systemTimeZone(), KCalendarCore::EventSortStartDate, KCalendarCore::SortDirectionAscending);
+        for (const KCalendarCore::Event::Ptr &event : std::as_const(events)) {
             if (event->hasRecurrenceId()) {
                 continue;
             }
@@ -377,13 +344,12 @@ void TimelineView::showDates(const QDate &start, const QDate &end, const QDate &
         }
     }
     d->mGantt->setModel(ganttModel);
-    d->splitterMoved();
 }
 
 void TimelineView::showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date)
 {
-    Q_UNUSED(incidenceList);
-    Q_UNUSED(date);
+    Q_UNUSED(incidenceList)
+    Q_UNUSED(date)
 }
 
 void TimelineView::updateView()
@@ -432,19 +398,16 @@ QDate TimelineView::endDate() const
 bool TimelineView::eventFilter(QObject *object, QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
-        QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+        auto helpEvent = static_cast<QHelpEvent *>(event);
         QGraphicsItem *item = d->mGantt->itemAt(helpEvent->pos());
         if (item) {
             if (item->type() == KGantt::GraphicsItem::Type) {
-                KGantt::GraphicsItem *graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
+                auto graphicsItem = static_cast<KGantt::GraphicsItem *>(item);
                 const QModelIndex itemIndex = graphicsItem->index();
 
-                QStandardItemModel *itemModel
-                    = qobject_cast<QStandardItemModel *>(d->mGantt->model());
+                auto itemModel = qobject_cast<QStandardItemModel *>(d->mGantt->model());
 
-                TimelineSubItem *timelineItem
-                    = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(),
-                                                                      itemIndex.column()));
+                auto timelineItem = dynamic_cast<TimelineSubItem *>(itemModel->item(itemIndex.row(), itemIndex.column()));
 
                 if (timelineItem) {
                     timelineItem->updateToolTip();
