@@ -1,29 +1,13 @@
 /*
-  Copyright (c) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#include "incidencetreemodel_p.h"
 #include "calendarview_debug.h"
+#include "incidencetreemodel_p.h"
 
-#include <AkonadiCore/EntityTreeModel>
+#include <Akonadi/EntityTreeModel>
 
 using namespace Akonadi;
 QDebug operator<<(QDebug s, const Node::Ptr &node);
@@ -32,7 +16,7 @@ static void calculateDepth(const Node::Ptr &node)
 {
     Q_ASSERT(node);
     node->depth = node->parentNode ? 1 + node->parentNode->depth : 0;
-    for (const Node::Ptr &child : qAsConst(node->directChilds)) {
+    for (const Node::Ptr &child : std::as_const(node->directChilds)) {
         calculateDepth(child);
     }
 }
@@ -59,12 +43,12 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
     PreNode::List remainingNodes = nodes;
 
     while (prenodeByUid.count() < count) {
-        const auto preSize = prenodeByUid.count(); // this saves us from infinit looping if the parent doesn't exist
+        const auto preSize = prenodeByUid.count(); // this saves us from infinite looping if the parent doesn't exist
         for (const PreNode::Ptr &node : nodes) {
             Q_ASSERT(node);
             const QString uid = node->incidence->instanceIdentifier();
             const QString parentUid = node->incidence->relatedTo();
-            if (parentUid.isEmpty()) {   // toplevel todo
+            if (parentUid.isEmpty()) { // toplevel todo
                 prenodeByUid.insert(uid, node);
                 remainingNodes.removeAll(node);
                 node->depth = 0;
@@ -87,25 +71,22 @@ static PreNode::List sortedPrenodes(const PreNode::List &nodes)
     return sorted;
 }
 
-IncidenceTreeModel::Private::Private(IncidenceTreeModel *qq, const QStringList &mimeTypes)
+IncidenceTreeModelPrivate::IncidenceTreeModelPrivate(IncidenceTreeModel *qq, const QStringList &mimeTypes)
     : QObject()
     , m_mimeTypes(mimeTypes)
     , q(qq)
 {
 }
 
-int IncidenceTreeModel::Private::rowForNode(const Node::Ptr &node) const
+int IncidenceTreeModelPrivate::rowForNode(const Node::Ptr &node) const
 {
     // Returns it's row number
-    const int row
-        = node->parentNode
-          ? node->parentNode->directChilds.indexOf(node)
-          : m_toplevelNodeList.indexOf(node);
+    const int row = node->parentNode ? node->parentNode->directChilds.indexOf(node) : m_toplevelNodeList.indexOf(node);
     Q_ASSERT(row != -1);
     return row;
 }
 
-void IncidenceTreeModel::Private::assert_and_dump(bool condition, const QString &message)
+void IncidenceTreeModelPrivate::assert_and_dump(bool condition, const QString &message)
 {
     if (!condition) {
         qCCritical(CALENDARVIEW_LOG) << "This should never happen: " << message;
@@ -114,26 +95,25 @@ void IncidenceTreeModel::Private::assert_and_dump(bool condition, const QString
     }
 }
 
-void IncidenceTreeModel::Private::dumpTree()
+void IncidenceTreeModelPrivate::dumpTree()
 {
-    for (const Node::Ptr &node : qAsConst(m_toplevelNodeList)) {
+    for (const Node::Ptr &node : std::as_const(m_toplevelNodeList)) {
         qCDebug(CALENDARVIEW_LOG) << node;
     }
 }
 
-QModelIndex IncidenceTreeModel::Private::indexForNode(const Node::Ptr &node) const
+QModelIndex IncidenceTreeModelPrivate::indexForNode(const Node::Ptr &node) const
 {
     if (!node) {
-        return QModelIndex();
+        return {};
     }
-    const int row = node->parentNode ? node->parentNode->directChilds.indexOf(node)
-                    : m_toplevelNodeList.indexOf(node);
+    const int row = node->parentNode ? node->parentNode->directChilds.indexOf(node) : m_toplevelNodeList.indexOf(node);
 
     Q_ASSERT(row != -1);
     return q->createIndex(row, 0, node.data());
 }
 
-void IncidenceTreeModel::Private::reset(bool silent)
+void IncidenceTreeModelPrivate::reset(bool silent)
 {
     if (!silent) {
         q->beginResetModel();
@@ -147,10 +127,8 @@ void IncidenceTreeModel::Private::reset(bool silent)
         const int sourceCount = q->sourceModel()->rowCount();
         for (int i = 0; i < sourceCount; ++i) {
             PreNode::Ptr prenode = prenodeFromSourceRow(i);
-            if (prenode
-                && (m_mimeTypes.isEmpty()
-                    || m_mimeTypes.contains(prenode->incidence->mimeType()))) {
-                insertNode(prenode, /**silent=*/ true);
+            if (prenode && (m_mimeTypes.isEmpty() || m_mimeTypes.contains(prenode->incidence->mimeType()))) {
+                insertNode(prenode, /**silent=*/true);
             }
         }
     }
@@ -159,13 +137,12 @@ void IncidenceTreeModel::Private::reset(bool silent)
     }
 }
 
-void IncidenceTreeModel::Private::onHeaderDataChanged(Qt::Orientation orientation, int first,
-                                                      int last)
+void IncidenceTreeModelPrivate::onHeaderDataChanged(Qt::Orientation orientation, int first, int last)
 {
     Q_EMIT q->headerDataChanged(orientation, first, last);
 }
 
-void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
+void IncidenceTreeModelPrivate::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
 {
     Q_ASSERT(begin.isValid());
     Q_ASSERT(end.isValid());
@@ -187,18 +164,15 @@ void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const
             // Did we this node change parent? If no, just Q_EMIT dataChanged(), if
             // yes, we must Q_EMIT rowsMoved(), so we see a visual effect in the view.
             Node *rawNode = reinterpret_cast<Node *>(index.internalPointer());
-            Node::Ptr node = m_uidMap.value(rawNode->uid);   // Looks hackish but it's safe
+            Node::Ptr node = m_uidMap.value(rawNode->uid); // Looks hackish but it's safe
             Q_ASSERT(node);
             Node::Ptr oldParentNode = node->parentNode;
-            Akonadi::Item item = q->data(index,
-                                         Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+            auto item = q->data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
             Q_ASSERT(item.isValid());
-            KCalendarCore::Incidence::Ptr incidence
-                = !item.hasPayload<KCalendarCore::Incidence::Ptr>() ? KCalendarCore::Incidence::Ptr()
-                  : item.payload<KCalendarCore::Incidence::Ptr>();
+            KCalendarCore::Incidence::Ptr incidence =
+                !item.hasPayload<KCalendarCore::Incidence::Ptr>() ? KCalendarCore::Incidence::Ptr() : item.payload<KCalendarCore::Incidence::Ptr>();
             if (!incidence) {
-                qCCritical(CALENDARVIEW_LOG) << "Incidence shouldn't be invalid."
-                                             << item.hasPayload() << item.id();
+                qCCritical(CALENDARVIEW_LOG) << "Incidence shouldn't be invalid." << item.hasPayload() << item.id();
                 Q_ASSERT(false);
                 return;
             }
@@ -239,21 +213,20 @@ void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const
                     toRow = m_toplevelNodeList.count();
                 }
 
-                const bool res = q->beginMoveRows(/**fromParent*/ index.parent(), fromRow,
-                                                                  fromRow, newParentIndex, toRow);
+                const bool res = q->beginMoveRows(/**fromParent*/ index.parent(), fromRow, fromRow, newParentIndex, toRow);
                 Q_ASSERT(res);
-                Q_UNUSED(res);
+                Q_UNUSED(res)
 
                 // Now that beginmoveRows() was called, we can do the actual moving:
                 if (newParentNode) {
-                    newParentNode->directChilds.append(node);   // Add to new parent
+                    newParentNode->directChilds.append(node); // Add to new parent
                     node->parentNode = newParentNode;
 
                     if (oldParentNode) {
-                        oldParentNode->directChilds.remove(fromRow);   // Remove from parent
+                        oldParentNode->directChilds.remove(fromRow); // Remove from parent
                         Q_ASSERT(oldParentNode->directChilds.indexOf(node) == -1);
                     } else {
-                        m_toplevelNodeList.remove(fromRow);   // Remove from root
+                        m_toplevelNodeList.remove(fromRow); // Remove from root
                         Q_ASSERT(m_toplevelNodeList.indexOf(node) == -1);
                     }
                 } else {
@@ -280,23 +253,22 @@ void IncidenceTreeModel::Private::onDataChanged(const QModelIndex &begin, const
     }
 }
 
-void IncidenceTreeModel::Private::onRowsAboutToBeInserted(const QModelIndex &parent, int, int)
+void IncidenceTreeModelPrivate::onRowsAboutToBeInserted(const QModelIndex &parent, int, int)
 {
     // We are a reparenting proxy, the source proxy is flat
     Q_ASSERT(!parent.isValid());
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     // Nothing to do yet. We don't know if all the new incidences in this range belong to the same
     // parent yet.
 }
 
-PreNode::Ptr IncidenceTreeModel::Private::prenodeFromSourceRow(int row) const
+PreNode::Ptr IncidenceTreeModelPrivate::prenodeFromSourceRow(int row) const
 {
     PreNode::Ptr node = PreNode::Ptr(new PreNode());
     node->sourceIndex = q->sourceModel()->index(row, 0, QModelIndex());
     Q_ASSERT(node->sourceIndex.isValid());
     Q_ASSERT(node->sourceIndex.model() == q->sourceModel());
-    const Akonadi::Item item
-        = node->sourceIndex.data(EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto item = node->sourceIndex.data(EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
     if (!item.isValid()) {
         // It's a Collection, ignore that, we only want items.
@@ -310,19 +282,18 @@ PreNode::Ptr IncidenceTreeModel::Private::prenodeFromSourceRow(int row) const
     return node;
 }
 
-void IncidenceTreeModel::Private::onRowsInserted(const QModelIndex &parent, int begin, int end)
+void IncidenceTreeModelPrivate::onRowsInserted(const QModelIndex &parent, int begin, int end)
 {
-    //QElapsedTimer timer;
-    //timer.start();
+    // QElapsedTimer timer;
+    // timer.start();
     Q_ASSERT(!parent.isValid());
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     Q_ASSERT(begin <= end);
     PreNode::List nodes;
     for (int i = begin; i <= end; ++i) {
         PreNode::Ptr node = prenodeFromSourceRow(i);
         // if m_mimeTypes is empty, we ignore this feature
-        if (!node
-            || (!m_mimeTypes.isEmpty() && !m_mimeTypes.contains(node->incidence->mimeType()))) {
+        if (!node || (!m_mimeTypes.isEmpty() && !m_mimeTypes.contains(node->incidence->mimeType()))) {
             continue;
         }
         nodes << node;
@@ -338,10 +309,10 @@ void IncidenceTreeModel::Private::onRowsInserted(const QModelIndex &parent, int
     if (end > begin) {
         Q_EMIT q->batchInsertionFinished();
     }
-    //qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to insert " << end-begin+1;
+    // qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to insert " << end-begin+1;
 }
 
-void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool silent)
+void IncidenceTreeModelPrivate::insertNode(const PreNode::Ptr &prenode, bool silent)
 {
     KCalendarCore::Incidence::Ptr incidence = prenode->incidence;
     Akonadi::Item item = prenode->item;
@@ -350,19 +321,16 @@ void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool s
     node->id = item.id();
     node->uid = incidence->instanceIdentifier();
     m_itemByUid.insert(node->uid, item);
-    //qCDebug(CALENDARVIEW_LOG) << "New node " << node.data() << node->uid << node->id;
+    // qCDebug(CALENDARVIEW_LOG) << "New node " << node.data() << node->uid << node->id;
     node->parentUid = incidence->relatedTo();
     if (node->uid == node->parentUid) {
-        qCWarning(CALENDARVIEW_LOG) << "Incidence with itself as parent!" << node->uid
-                                    << "Akonadi item" << item.id() << "remoteId="
-                                    << item.remoteId();
+        qCWarning(CALENDARVIEW_LOG) << "Incidence with itself as parent!" << node->uid << "Akonadi item" << item.id() << "remoteId=" << item.remoteId();
         node->parentUid.clear();
     }
 
     if (m_uidMap.contains(node->uid)) {
-        qCWarning(CALENDARVIEW_LOG)
-            << "Duplicate incidence detected. File a bug against the resource. collection="
-            << item.storageCollectionId();
+        qCWarning(CALENDARVIEW_LOG) << "Duplicate incidence detected:"
+                                    << "uid=" << node->uid << ". File a bug against the resource. collection=" << item.storageCollectionId();
         return;
     }
 
@@ -414,47 +382,47 @@ void IncidenceTreeModel::Private::insertNode(const PreNode::Ptr &prenode, bool s
     // Are we a parent?
     if (m_waitingForParent.contains(node->uid)) {
         Q_ASSERT(m_waitingForParent.count(node->uid) > 0);
-        const QList<Node::Ptr> childs = m_waitingForParent.values(node->uid);
+        const QList<Node::Ptr> children = m_waitingForParent.values(node->uid);
         m_waitingForParent.remove(node->uid);
-        Q_ASSERT(!childs.isEmpty());
+        Q_ASSERT(!children.isEmpty());
 
-        for (const Node::Ptr &child : childs) {
+        for (const Node::Ptr &child : children) {
             const int fromRow = m_toplevelNodeList.indexOf(child);
             Q_ASSERT(fromRow != -1);
             const QModelIndex toParent = indexForNode(node);
             Q_ASSERT(toParent.isValid());
             Q_ASSERT(toParent.model() == q);
-            //const int toRow = node->directChilds.count();
+            // const int toRow = node->directChilds.count();
 
             if (!silent) {
-                //const bool res = q->beginMoveRows( /**fromParent*/QModelIndex(), fromRow,
+                // const bool res = q->beginMoveRows( /**fromParent*/QModelIndex(), fromRow,
                 //                                 fromRow, toParent, toRow );
-                //Q_EMIT q->layoutAboutToBeChanged();
+                // Q_EMIT q->layoutAboutToBeChanged();
                 q->beginResetModel();
-                //Q_ASSERT( res );
+                // Q_ASSERT( res );
             }
             child->parentNode = node;
             node->directChilds.append(child);
             m_toplevelNodeList.remove(fromRow);
 
             if (!silent) {
-                //q->endMoveRows();
+                // q->endMoveRows();
                 q->endResetModel();
-                //Q_EMIT q->layoutChanged();
+                // Q_EMIT q->layoutChanged();
             }
         }
     }
 }
 
-// Sorts childs first parents last
-Node::List IncidenceTreeModel::Private::sorted(const Node::List &nodes) const
+// Sorts children first parents last
+Node::List IncidenceTreeModelPrivate::sorted(const Node::List &nodes) const
 {
     if (nodes.isEmpty()) {
         return nodes;
     }
 
     // Initialize depths
-    for (const Node::Ptr &topLevelNode : qAsConst(m_toplevelNodeList)) {
+    for (const Node::Ptr &topLevelNode : std::as_const(m_toplevelNodeList)) {
         calculateDepth(topLevelNode);
     }
 
@@ -464,13 +432,12 @@ Node::List IncidenceTreeModel::Private::sorted(const Node::List &nodes) const
     return sorted;
 }
 
-void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin,
-                                                         int end)
+void IncidenceTreeModelPrivate::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
 {
-    //QElapsedTimer timer;
-    //timer.start();
+    // QElapsedTimer timer;
+    // timer.start();
     Q_ASSERT(!parent.isValid());
-    Q_UNUSED(parent);
+    Q_UNUSED(parent)
     Q_ASSERT(begin <= end);
 
     // First, gather nodes to remove
@@ -491,47 +458,47 @@ void IncidenceTreeModel::Private::onRowsAboutToBeRemoved(const QModelIndex &pare
         nodesToRemove << node;
     }
 
-    // We want to remove childs first, to avoid row moving
+    // We want to remove children first, to avoid row moving
     const Node::List nodesToRemoveSorted = sorted(nodesToRemove);
 
     for (const Node::Ptr &node : nodesToRemoveSorted) {
         // Go ahead and remove it now. We don't do it in ::onRowsRemoved(), because
-        // while unparenting childs with moveRows() the view might call data() on the
+        // while unparenting children with moveRows() the view might call data() on the
         // item that is already removed from ETM.
         removeNode(node);
-        //qCDebug(CALENDARVIEW_LOG) << "Just removed a node, here's the tree";
-        //dumpTree();
+        // qCDebug(CALENDARVIEW_LOG) << "Just removed a node, here's the tree";
+        // dumpTree();
     }
 
     m_removedNodes.clear();
-    //qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to remove " << end-begin+1;
+    // qCDebug(CALENDARVIEW_LOG) << "Took " << timer.elapsed() << " to remove " << end-begin+1;
 }
 
-void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
+void IncidenceTreeModelPrivate::removeNode(const Node::Ptr &node)
 {
     Q_ASSERT(node);
-    //qCDebug(CALENDARVIEW_LOG) << "Dealing with parent: " << node->id << node.data()
+    // qCDebug(CALENDARVIEW_LOG) << "Dealing with parent: " << node->id << node.data()
     //         << node->uid << node->directChilds.count() << indexForNode( node );
 
     // First, unparent the children
     if (!node->directChilds.isEmpty()) {
-        const Node::List childs = node->directChilds;
+        const Node::List children = node->directChilds;
         const QModelIndex fromParent = indexForNode(node);
         Q_ASSERT(fromParent.isValid());
-//    const int firstSourceRow = 0;
+        //    const int firstSourceRow = 0;
         //  const int lastSourceRow  = node->directChilds.count() - 1;
-        //const int toRow = m_toplevelNodeList.count();
-        //q->beginMoveRows( fromParent, firstSourceRow, lastSourceRow,
+        // const int toRow = m_toplevelNodeList.count();
+        // q->beginMoveRows( fromParent, firstSourceRow, lastSourceRow,
         //                  /**toParent is root*/QModelIndex(), toRow );
         q->beginResetModel();
         node->directChilds.clear();
-        for (const Node::Ptr &child : childs) {
-            //qCDebug(CALENDARVIEW_LOG) << "Dealing with child: " << child.data() << child->uid;
+        for (const Node::Ptr &child : children) {
+            // qCDebug(CALENDARVIEW_LOG) << "Dealing with child: " << child.data() << child->uid;
             m_toplevelNodeList.append(child);
             child->parentNode = Node::Ptr();
             m_waitingForParent.insert(node->uid, child);
         }
-        //q->endMoveRows();
+        // q->endMoveRows();
         q->endResetModel();
     }
 
@@ -562,144 +529,117 @@ void IncidenceTreeModel::Private::removeNode(const Node::Ptr &node)
     m_removedNodes << node.data();
 }
 
-void IncidenceTreeModel::Private::onRowsRemoved(const QModelIndex &parent, int begin, int end)
+void IncidenceTreeModelPrivate::onRowsRemoved(const QModelIndex &parent, int begin, int end)
 {
-    Q_UNUSED(parent);
-    Q_UNUSED(begin);
-    Q_UNUSED(end);
+    Q_UNUSED(parent)
+    Q_UNUSED(begin)
+    Q_UNUSED(end)
     // Nothing to do here, see comment on ::onRowsAboutToBeRemoved()
 }
 
-void IncidenceTreeModel::Private::onModelAboutToBeReset()
+void IncidenceTreeModelPrivate::onModelAboutToBeReset()
 {
     q->beginResetModel();
 }
 
-void IncidenceTreeModel::Private::onModelReset()
+void IncidenceTreeModelPrivate::onModelReset()
 {
-    reset(/**silent=*/ false);
+    reset(/**silent=*/false);
     q->endResetModel();
 }
 
-void IncidenceTreeModel::Private::onLayoutAboutToBeChanged()
+void IncidenceTreeModelPrivate::onLayoutAboutToBeChanged()
 {
     Q_ASSERT(q->persistentIndexList().isEmpty());
     Q_EMIT q->layoutAboutToBeChanged();
 }
 
-void IncidenceTreeModel::Private::onLayoutChanged()
+void IncidenceTreeModelPrivate::onLayoutChanged()
 {
-    reset(/**silent=*/ true);
+    reset(/**silent=*/true);
     Q_ASSERT(q->persistentIndexList().isEmpty());
     Q_EMIT q->layoutChanged();
 }
 
-void IncidenceTreeModel::Private::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
+void IncidenceTreeModelPrivate::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
 {
     // Not implemented yet
     Q_ASSERT(false);
 }
 
-void IncidenceTreeModel::Private::setSourceModel(QAbstractItemModel *model)
+void IncidenceTreeModelPrivate::setSourceModel(QAbstractItemModel *model)
 {
     q->beginResetModel();
 
     if (q->sourceModel()) {
-        disconnect(q->sourceModel(), &IncidenceTreeModel::dataChanged,
-                   this, &IncidenceTreeModel::Private::onDataChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModelPrivate::onDataChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged,
-                   this, &IncidenceTreeModel::Private::onHeaderDataChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModelPrivate::onHeaderDataChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsInserted,
-                   this, &IncidenceTreeModel::Private::onRowsInserted);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModelPrivate::onRowsInserted);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved,
-                   this, &IncidenceTreeModel::Private::onRowsRemoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModelPrivate::onRowsRemoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsMoved,
-                   this, &IncidenceTreeModel::Private::onRowsMoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModelPrivate::onRowsMoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted,
-                   this, &IncidenceTreeModel::Private::onRowsAboutToBeInserted);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModelPrivate::onRowsAboutToBeInserted);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved,
-                   this, &IncidenceTreeModel::Private::onRowsAboutToBeRemoved);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModelPrivate::onRowsAboutToBeRemoved);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset,
-                   this, &IncidenceTreeModel::Private::onModelAboutToBeReset);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModelPrivate::onModelAboutToBeReset);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::modelReset,
-                   this, &IncidenceTreeModel::Private::onModelReset);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModelPrivate::onModelReset);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged,
-                   this, &IncidenceTreeModel::Private::onLayoutAboutToBeChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModelPrivate::onLayoutAboutToBeChanged);
 
-        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutChanged,
-                   this, &IncidenceTreeModel::Private::onLayoutChanged);
+        disconnect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModelPrivate::onLayoutChanged);
     }
 
     q->QAbstractProxyModel::setSourceModel(model);
 
     if (q->sourceModel()) {
-        connect(q->sourceModel(), &IncidenceTreeModel::dataChanged,
-                this, &IncidenceTreeModel::Private::onDataChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::dataChanged, this, &IncidenceTreeModelPrivate::onDataChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged,
-                this, &IncidenceTreeModel::Private::onHeaderDataChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::headerDataChanged, this, &IncidenceTreeModelPrivate::onHeaderDataChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted,
-                this, &IncidenceTreeModel::Private::onRowsAboutToBeInserted);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeInserted, this, &IncidenceTreeModelPrivate::onRowsAboutToBeInserted);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsInserted,
-                this, &IncidenceTreeModel::Private::onRowsInserted);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsInserted, this, &IncidenceTreeModelPrivate::onRowsInserted);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved,
-                this, &IncidenceTreeModel::Private::onRowsAboutToBeRemoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsAboutToBeRemoved, this, &IncidenceTreeModelPrivate::onRowsAboutToBeRemoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved,
-                this, &IncidenceTreeModel::Private::onRowsRemoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsRemoved, this, &IncidenceTreeModelPrivate::onRowsRemoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::rowsMoved,
-                this, &IncidenceTreeModel::Private::onRowsMoved);
+        connect(q->sourceModel(), &IncidenceTreeModel::rowsMoved, this, &IncidenceTreeModelPrivate::onRowsMoved);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset,
-                this, &IncidenceTreeModel::Private::onModelAboutToBeReset);
+        connect(q->sourceModel(), &IncidenceTreeModel::modelAboutToBeReset, this, &IncidenceTreeModelPrivate::onModelAboutToBeReset);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::modelReset,
-                this, &IncidenceTreeModel::Private::onModelReset);
+        connect(q->sourceModel(), &IncidenceTreeModel::modelReset, this, &IncidenceTreeModelPrivate::onModelReset);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged,
-                this, &IncidenceTreeModel::Private::onLayoutAboutToBeChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::layoutAboutToBeChanged, this, &IncidenceTreeModelPrivate::onLayoutAboutToBeChanged);
 
-        connect(q->sourceModel(), &IncidenceTreeModel::layoutChanged,
-                this, &IncidenceTreeModel::Private::onLayoutChanged);
+        connect(q->sourceModel(), &IncidenceTreeModel::layoutChanged, this, &IncidenceTreeModelPrivate::onLayoutChanged);
     }
 
-    reset(/**silent=*/ true);
+    reset(/**silent=*/true);
     q->endResetModel();
 }
 
-
-
 IncidenceTreeModel::IncidenceTreeModel(QObject *parent)
     : QAbstractProxyModel(parent)
-    , d(new Private(this, QStringList()))
+    , d(new IncidenceTreeModelPrivate(this, QStringList()))
 {
     setObjectName(QStringLiteral("IncidenceTreeModel"));
 }
 
 IncidenceTreeModel::IncidenceTreeModel(const QStringList &mimeTypes, QObject *parent)
     : QAbstractProxyModel(parent)
-    , d(new Private(this, mimeTypes))
+    , d(new IncidenceTreeModelPrivate(this, mimeTypes))
 {
     setObjectName(QStringLiteral("IncidenceTreeModel"));
 }
 
-IncidenceTreeModel::~IncidenceTreeModel()
-{
-    delete d;
-}
+IncidenceTreeModel::~IncidenceTreeModel() = default;
 
 QVariant IncidenceTreeModel::data(const QModelIndex &index, int role) const
 {
@@ -720,9 +660,7 @@ int IncidenceTreeModel::rowCount(const QModelIndex &parent) const
         Q_ASSERT(parent.model() == this);
         Node *parentNode = reinterpret_cast<Node *>(parent.internalPointer());
         Q_ASSERT(parentNode);
-        d->assert_and_dump(!d->m_removedNodes.contains(parentNode),
-                           QString::number((quintptr)parentNode,
-                                           16) + QLatin1String(" was already deleted"));
+        d->assert_and_dump(!d->m_removedNodes.contains(parentNode), QString::number((quintptr)parentNode, 16) + QLatin1String(" was already deleted"));
 
         const int count = parentNode->directChilds.count();
         return count;
@@ -750,10 +688,9 @@ void IncidenceTreeModel::setSourceModel(QAbstractItemModel *model)
 QModelIndex IncidenceTreeModel::mapFromSource(const QModelIndex &sourceIndex) const
 {
     if (!sourceIndex.isValid()) {
-        qCWarning(CALENDARVIEW_LOG)
-            << "IncidenceTreeModel::mapFromSource() source index is invalid";
+        qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::mapFromSource() source index is invalid";
         // Q_ASSERT( false );
-        return QModelIndex();
+        return {};
     }
 
     if (!sourceModel()) {
@@ -761,8 +698,7 @@ QModelIndex IncidenceTreeModel::mapFromSource(const QModelIndex &sourceIndex) co
     }
     Q_ASSERT(sourceIndex.column() < sourceModel()->columnCount());
     Q_ASSERT(sourceModel() == sourceIndex.model());
-    const Akonadi::Item::Id id
-        = sourceIndex.data(Akonadi::EntityTreeModel::ItemIdRole).toLongLong();
+    const Akonadi::Item::Id id = sourceIndex.data(Akonadi::EntityTreeModel::ItemIdRole).toLongLong();
 
     if (id == -1 || !d->m_nodeMap.contains(id)) {
         return QModelIndex();
@@ -777,7 +713,7 @@ QModelIndex IncidenceTreeModel::mapFromSource(const QModelIndex &sourceIndex) co
 QModelIndex IncidenceTreeModel::mapToSource(const QModelIndex &proxyIndex) const
 {
     if (!proxyIndex.isValid() || !sourceModel()) {
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(proxyIndex.column() < columnCount());
@@ -800,8 +736,7 @@ QModelIndex IncidenceTreeModel::mapToSource(const QModelIndex &proxyIndex) const
     QModelIndex index = indexes.first();*/
     QModelIndex index = node->sourceIndex;
     if (!index.isValid()) {
-        qCWarning(CALENDARVIEW_LOG)
-            << "IncidenceTreeModel::mapToSource(): sourceModelIndex is invalid";
+        qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::mapToSource(): sourceModelIndex is invalid";
         Q_ASSERT(false);
         return QModelIndex();
     }
@@ -815,7 +750,7 @@ QModelIndex IncidenceTreeModel::parent(const QModelIndex &child) const
     if (!child.isValid()) {
         qCWarning(CALENDARVIEW_LOG) << "IncidenceTreeModel::parent(): child is invalid";
         Q_ASSERT(false);
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(child.model() == this);
@@ -853,7 +788,7 @@ QModelIndex IncidenceTreeModel::index(int row, int column, const QModelIndex &pa
                    << "; row=" << row << "; column=" << column
                    << "; rowCount() = " << rowCount( parent ); */
         // Q_ASSERT( false );
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(column >= 0);
@@ -865,14 +800,12 @@ QModelIndex IncidenceTreeModel::index(int row, int column, const QModelIndex &pa
         Node *parentNode = reinterpret_cast<Node *>(parent.internalPointer());
 
         if (row >= parentNode->directChilds.count()) {
-            qCCritical(CALENDARVIEW_LOG) << "IncidenceTreeModel::index() row=" << row
-                                         << "; column=" << column;
+            qCCritical(CALENDARVIEW_LOG) << "IncidenceTreeModel::index() row=" << row << "; column=" << column;
             Q_ASSERT(false);
             return QModelIndex();
         }
 
-        return createIndex(row, column,
-                           parentNode->directChilds.at(row).data());
+        return createIndex(row, column, parentNode->directChilds.at(row).data());
     } else {
         Q_ASSERT(row < d->m_toplevelNodeList.count());
         Node::Ptr node = d->m_toplevelNodeList.at(row);
@@ -919,11 +852,10 @@ QDebug operator<<(QDebug s, const Node::Ptr &node)
     static int level = 0;
     ++level;
     QString padding = QString(level - 1, QLatin1Char(' '));
-    s << padding + QLatin1String("node") << node.data() << QStringLiteral(";uid=") << node->uid
-      << QStringLiteral(";id=") << node->id << QStringLiteral(";parentUid=") << node->parentUid
-      << QStringLiteral(";parentNode=") << (void *)(node->parentNode.data()) << '\n';
+    s << padding + QLatin1String("node") << node.data() << QStringLiteral(";uid=") << node->uid << QStringLiteral(";id=") << node->id
+      << QStringLiteral(";parentUid=") << node->parentUid << QStringLiteral(";parentNode=") << (void *)(node->parentNode.data()) << '\n';
 
-    for (const Node::Ptr &child : qAsConst(node->directChilds)) {
+    for (const Node::Ptr &child : std::as_const(node->directChilds)) {
         s << child;
     }
 
