@@ -1,37 +1,24 @@
 /*
-  Copyright (c) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef INCIDENCE_TREEMODEL_H
-#define INCIDENCE_TREEMODEL_H
+#pragma once
 
-#include <AkonadiCore/Item>
+#include "eventviews_export.h"
+#include <Akonadi/Item>
 
 #include <QAbstractProxyModel>
 
-class IncidenceTreeModel : public QAbstractProxyModel
+#include <memory>
+
+class IncidenceTreeModelPrivate;
+
+class EVENTVIEWS_EXPORT IncidenceTreeModel : public QAbstractProxyModel
 {
     Q_OBJECT
 public:
-
     /**
      * Constructs a new IncidenceTreeModel.
      */
@@ -93,8 +80,7 @@ Q_SIGNALS:
     void batchInsertionFinished();
 
 private:
-    class Private;
-    Private *const d;
+    friend class IncidenceTreeModelPrivate;
+    std::unique_ptr<IncidenceTreeModelPrivate> const d;
 };
 
-#endif
