@@ -8,7 +8,7 @@
 
 #include "incidencetreemodel.h"
 
-#include <AkonadiCore/Item>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Incidence>
 #include <QHash>
@@ -50,11 +50,11 @@ struct PreNode {
     }
 };
 
-class IncidenceTreeModel::Private : public QObject
+class IncidenceTreeModelPrivate : public QObject
 {
     Q_OBJECT
 public:
-    Private(IncidenceTreeModel *qq, const QStringList &mimeTypes);
+    IncidenceTreeModelPrivate(IncidenceTreeModel *qq, const QStringList &mimeTypes);
     void reset(bool silent = false);
     void insertNode(const PreNode::Ptr &node, bool silent = false);
     void insertNode(const QModelIndex &sourceIndex, bool silent = false);
