@@ -1,49 +1,30 @@
 /*
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2012 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2012 Sérgio Martins <iamsergio@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#include "todomodel_p.h"
 #include "incidencetreemodel.h"
+#include "todomodel_p.h"
 
-#include <CalendarSupport/Utils>
 #include <CalendarSupport/KCalPrefs>
-#include <KLocalizedString>
-#include <KCalendarCore/Todo>
-#include <KCalendarCore/Event>
-#include <KCalendarCore/Attachment>
+#include <CalendarSupport/Utils>
 #include <KCalUtils/IncidenceFormatter>
+#include <KCalendarCore/Attachment>
+#include <KCalendarCore/Event>
 #include <KEmailAddress>
+#include <KLocalizedString>
 
 #include <KCalUtils/DndFactory>
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 
-#include <Akonadi/Calendar/ETMCalendar>
-
-#include <KMessageBox>
 #include "calendarview_debug.h"
+#include <KMessageBox>
 
-#include <QMimeData>
 #include <QIcon>
+#include <QMimeData>
 
 struct SourceModelIndex {
     SourceModelIndex(int _r, int _c, void *_p, QAbstractItemModel *_m)
@@ -69,18 +50,18 @@ static bool isDueToday(const KCalendarCore::Todo::Ptr &todo)
     return !todo->isCompleted() && todo->dtDue().date() == QDate::currentDate();
 }
 
-TodoModel::Private::Private(const EventViews::PrefsPtr &preferences, TodoModel *qq) : QObject()
-    , m_changer(nullptr)
+TodoModelPrivate::TodoModelPrivate(const EventViews::PrefsPtr &preferences, TodoModel *qq)
+    : QObject()
     , m_preferences(preferences)
     , q(qq)
 {
 }
 
-Akonadi::Item TodoModel::Private::findItemByUid(const QString &uid, const QModelIndex &parent) const
+Akonadi::Item TodoModelPrivate::findItemByUid(const QString &uid, const QModelIndex &parent) const
 {
     Q_ASSERT(!uid.isEmpty());
-    IncidenceTreeModel *treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
-    if (treeModel) {   // O(1) Shortcut
+    auto treeModel = qobject_cast<IncidenceTreeModel *>(q->sourceModel());
+    if (treeModel) { // O(1) Shortcut
         return treeModel->item(uid);
     }
 
@@ -103,7 +84,7 @@ Akonadi::Item TodoModel::Private::findItemByUid(const QString &uid, const QModel
     return item;
 }
 
-void TodoModel::Private::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
+void TodoModelPrivate::onDataChanged(const QModelIndex &begin, const QModelIndex &end)
 {
     Q_ASSERT(begin.isValid());
     Q_ASSERT(end.isValid());
@@ -113,80 +94,81 @@ void TodoModel::Private::onDataChanged(const QModelIndex &begin, const QModelInd
     Q_EMIT q->dataChanged(proxyBegin, proxyEnd.sibling(proxyEnd.row(), TodoModel::ColumnCount - 1));
 }
 
-void TodoModel::Private::onHeaderDataChanged(Qt::Orientation orientation, int first, int last)
+void TodoModelPrivate::onHeaderDataChanged(Qt::Orientation orientation, int first, int last)
 {
     Q_EMIT q->headerDataChanged(orientation, first, last);
 }
 
-void TodoModel::Private::onRowsAboutToBeInserted(const QModelIndex &parent, int begin, int end)
+void TodoModelPrivate::onRowsAboutToBeInserted(const QModelIndex &parent, int begin, int end)
 {
     const QModelIndex index = q->mapFromSource(parent);
-    Q_ASSERT(!(parent.isValid() ^ index.isValid()));     // Both must be valid, or both invalid
+    Q_ASSERT(!(parent.isValid() ^ index.isValid())); // Both must be valid, or both invalid
     Q_ASSERT(!(index.isValid() && index.model() != q));
 
     q->beginInsertRows(index, begin, end);
 }
 
-void TodoModel::Private::onRowsInserted(const QModelIndex &, int, int)
+void TodoModelPrivate::onRowsInserted(const QModelIndex &, int, int)
 {
     q->endInsertRows();
 }
 
-void TodoModel::Private::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
+void TodoModelPrivate::onRowsAboutToBeRemoved(const QModelIndex &parent, int begin, int end)
 {
     const QModelIndex index = q->mapFromSource(parent);
-    Q_ASSERT(!(parent.isValid() ^ index.isValid()));     // Both must be valid, or both invalid
+    Q_ASSERT(!(parent.isValid() ^ index.isValid())); // Both must be valid, or both invalid
     Q_ASSERT(!(index.isValid() && index.model() != q));
 
     q->beginRemoveRows(index, begin, end);
 }
 
-void TodoModel::Private::onRowsRemoved(const QModelIndex &, int, int)
+void TodoModelPrivate::onRowsRemoved(const QModelIndex &, int, int)
 {
     q->endRemoveRows();
 }
 
-void TodoModel::Private::onRowsAboutToBeMoved(const QModelIndex &sourceParent, int sourceStart,
-                                              int sourceEnd, const QModelIndex &destinationParent,
-                                              int destinationRow)
+void TodoModelPrivate::onRowsAboutToBeMoved(const QModelIndex &sourceParent,
+                                            int sourceStart,
+                                            int sourceEnd,
+                                            const QModelIndex &destinationParent,
+                                            int destinationRow)
 {
-    Q_UNUSED(sourceParent);
-    Q_UNUSED(sourceStart);
-    Q_UNUSED(sourceEnd);
-    Q_UNUSED(destinationParent);
-    Q_UNUSED(destinationRow);
+    Q_UNUSED(sourceParent)
+    Q_UNUSED(sourceStart)
+    Q_UNUSED(sourceEnd)
+    Q_UNUSED(destinationParent)
+    Q_UNUSED(destinationRow)
     /* Disabled for now, layoutAboutToBeChanged() is emitted
     q->beginMoveRows( q->mapFromSource( sourceParent ), sourceStart, sourceEnd,
                       q->mapFromSource( destinationParent ), destinationRow );
     */
 }
 
-void TodoModel::Private::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
+void TodoModelPrivate::onRowsMoved(const QModelIndex &, int, int, const QModelIndex &, int)
 {
     /*q->endMoveRows();*/
 }
 
-void TodoModel::Private::onModelAboutToBeReset()
+void TodoModelPrivate::onModelAboutToBeReset()
 {
     q->beginResetModel();
 }
 
-void TodoModel::Private::onModelReset()
+void TodoModelPrivate::onModelReset()
 {
     q->endResetModel();
 }
 
-void TodoModel::Private::onLayoutAboutToBeChanged()
+void TodoModelPrivate::onLayoutAboutToBeChanged()
 {
     Q_ASSERT(m_persistentIndexes.isEmpty());
     Q_ASSERT(m_layoutChangePersistentIndexes.isEmpty());
     Q_ASSERT(m_columns.isEmpty());
     const QModelIndexList persistentIndexes = q->persistentIndexList();
-    for (const QPersistentModelIndex &persistentIndex : persistentIndexes) {
+    for (const QModelIndex &persistentIndex : persistentIndexes) {
         m_persistentIndexes << persistentIndex; // Stuff we have to update onLayoutChanged
         Q_ASSERT(persistentIndex.isValid());
-        QModelIndex index_col0 = q->createIndex(persistentIndex.row(), 0,
-                                                persistentIndex.internalPointer());
+        QModelIndex index_col0 = q->createIndex(persistentIndex.row(), 0, persistentIndex.internalPointer());
         const QPersistentModelIndex srcPersistentIndex = q->mapToSource(index_col0);
         Q_ASSERT(srcPersistentIndex.isValid());
         m_layoutChangePersistentIndexes << srcPersistentIndex;
@@ -195,16 +177,13 @@ void TodoModel::Private::onLayoutAboutToBeChanged()
     Q_EMIT q->layoutAboutToBeChanged();
 }
 
-void TodoModel::Private::onLayoutChanged()
+void TodoModelPrivate::onLayoutChanged()
 {
     for (int i = 0; i < m_persistentIndexes.size(); ++i) {
         QModelIndex newIndex_col0 = q->mapFromSource(m_layoutChangePersistentIndexes.at(i));
         Q_ASSERT(newIndex_col0.isValid());
         const int column = m_columns.at(i);
-        QModelIndex newIndex
-            = column == 0
-              ? newIndex_col0
-              : q->createIndex(newIndex_col0.row(), column, newIndex_col0.internalPointer());
+        QModelIndex newIndex = column == 0 ? newIndex_col0 : q->createIndex(newIndex_col0.row(), column, newIndex_col0.internalPointer());
         q->changePersistentIndex(m_persistentIndexes.at(i), newIndex);
     }
 
@@ -216,15 +195,12 @@ void TodoModel::Private::onLayoutChanged()
 
 TodoModel::TodoModel(const EventViews::PrefsPtr &preferences, QObject *parent)
     : QAbstractProxyModel(parent)
-    , d(new Private(preferences, this))
+    , d(new TodoModelPrivate(preferences, this))
 {
     setObjectName(QStringLiteral("TodoModel"));
 }
 
-TodoModel::~TodoModel()
-{
-    delete d;
-}
+TodoModel::~TodoModel() = default;
 
 QVariant TodoModel::data(const QModelIndex &index, int role) const
 {
@@ -238,18 +214,17 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
     Q_ASSERT(sourceIndex.isValid());
-    const Akonadi::Item item
-        = sourceIndex.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto item = sourceIndex.data(Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     if (!item.isValid()) {
         qCWarning(CALENDARVIEW_LOG) << "Invalid index: " << sourceIndex;
-        //Q_ASSERT( false );
+        // Q_ASSERT( false );
         return QVariant();
     }
     const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
     if (!todo) {
         qCCritical(CALENDARVIEW_LOG) << "item.hasPayload()" << item.hasPayload();
         if (item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
-            KCalendarCore::Incidence::Ptr incidence = item.payload<KCalendarCore::Incidence::Ptr>();
+            auto incidence = item.payload<KCalendarCore::Incidence::Ptr>();
             if (incidence) {
                 qCCritical(CALENDARVIEW_LOG) << "It's actually " << incidence->type();
             }
@@ -259,6 +234,41 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         return QVariant();
     }
 
+    switch (role) {
+    case SummaryRole:
+        return todo->summary();
+    case RecurRole:
+        if (todo->recurs()) {
+            if (todo->hasRecurrenceId()) {
+                return i18nc("yes, an exception to a recurring to-do", "Exception");
+            } else {
+                return i18nc("yes, recurring to-do", "Yes");
+            }
+        } else {
+            return i18nc("no, not a recurring to-do", "No");
+        }
+    case PriorityRole:
+        if (todo->priority() == 0) {
+            return QStringLiteral("--");
+        }
+        return todo->priority();
+    case PercentRole:
+        return todo->percentComplete();
+    case StartDateRole:
+        return todo->hasStartDate() ? QLocale().toString(todo->dtStart().toLocalTime().date(), QLocale::ShortFormat) : QString();
+    case DueDateRole:
+        return todo->hasDueDate() ? QLocale().toString(todo->dtDue().toLocalTime().date(), QLocale::ShortFormat) : QString();
+    case CategoriesRole: {
+        return todo->categories().join(i18nc("delimiter for joining category/tag names", ","));
+    }
+    case DescriptionRole:
+        return todo->description();
+    case CalendarRole:
+        return CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection());
+    default:
+        break; // column based model handling
+    }
+
     if (role == Qt::DisplayRole) {
         switch (index.column()) {
         case SummaryColumn:
@@ -281,24 +291,19 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         case PercentColumn:
             return QVariant(todo->percentComplete());
         case StartDateColumn:
-            return todo->hasStartDate() ? QLocale().toString(
-                todo->dtStart().toLocalTime().date(), QLocale::ShortFormat)
-                   : QVariant(QString());
+            return todo->hasStartDate() ? QLocale().toString(todo->dtStart().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
         case DueDateColumn:
-            return todo->hasDueDate() ? QLocale().toString(
-                todo->dtDue().toLocalTime().date(), QLocale::ShortFormat)
-                   : QVariant(QString());
-        case CategoriesColumn:
-        {
-            QString categories = todo->categories().join(
-                i18nc("delimiter for joining category names", ","));
+            return todo->hasDueDate() ? QLocale().toString(todo->dtDue().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
+        case CompletedDateColumn:
+            return todo->hasCompletedDate() ? QLocale().toString(todo->completed().toLocalTime().date(), QLocale::ShortFormat) : QVariant(QString());
+        case CategoriesColumn: {
+            QString categories = todo->categories().join(i18nc("delimiter for joining category/tag names", ","));
             return QVariant(categories);
         }
         case DescriptionColumn:
             return QVariant(todo->description());
         case CalendarColumn:
-            return QVariant(CalendarSupport::displayName(d->m_calendar.data(),
-                                                         item.parentCollection()));
+            return QVariant(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()));
         }
         return QVariant();
     }
@@ -317,13 +322,14 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
             return QVariant(todo->dtStart().date());
         case DueDateColumn:
             return QVariant(todo->dtDue().date());
+        case CompletedDateColumn:
+            return QVariant(todo->completed().date());
         case CategoriesColumn:
             return QVariant(todo->categories());
         case DescriptionColumn:
             return QVariant(todo->description());
         case CalendarColumn:
-            return QVariant(CalendarSupport::displayName(d->m_calendar.data(),
-                                                         item.parentCollection()));
+            return QVariant(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()));
         }
         return QVariant();
     }
@@ -331,10 +337,8 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // set the tooltip for every item
     if (role == Qt::ToolTipRole) {
         if (d->m_preferences->enableToolTips()) {
-            return QVariant(KCalUtils::IncidenceFormatter::toolTipStr(
-                                CalendarSupport::displayName(d->m_calendar.data(),
-                                                             item.parentCollection()),
-                                todo, QDate(), true));
+            return QVariant(
+                KCalUtils::IncidenceFormatter::toolTipStr(CalendarSupport::displayName(d->m_calendar.data(), item.parentCollection()), todo, QDate(), true));
         } else {
             return QVariant();
         }
@@ -343,11 +347,9 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // background colour for todos due today or overdue todos
     if (role == Qt::BackgroundRole) {
         if (todo->isOverdue()) {
-            return QVariant(
-                QBrush(d->m_preferences->todoOverdueColor()));
+            return QVariant(QBrush(d->m_preferences->todoOverdueColor()));
         } else if (isDueToday(todo)) {
-            return QVariant(
-                QBrush(d->m_preferences->todoDueTodayColor()));
+            return QVariant(QBrush(d->m_preferences->todoDueTodayColor()));
         }
     }
 
@@ -367,18 +369,13 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
     // icon for recurring todos
     // It's in the summary column so you don't accidentally click
     // the checkbox ( which increments the next occurrence date ).
+    // category colour
     if (role == Qt::DecorationRole && index.column() == SummaryColumn) {
         if (todo->recurs()) {
             return QVariant(QIcon::fromTheme(QStringLiteral("task-recurring")));
         }
-    }
-
-    // category colour
-    if (role == Qt::DecorationRole && index.column() == SummaryColumn) {
-        QStringList categories = todo->categories();
-        return categories.isEmpty()
-               ? QVariant()
-               : QVariant(CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first()));
+        const QStringList categories = todo->categories();
+        return categories.isEmpty() ? QVariant() : QVariant(CalendarSupport::KCalPrefs::instance()->categoryColor(categories.first()));
     } else if (role == Qt::DecorationRole) {
         return QVariant();
     }
@@ -387,6 +384,10 @@ QVariant TodoModel::data(const QModelIndex &index, int role) const
         return QVariant::fromValue(item);
     }
 
+    if (role == TodoPtrRole) {
+        return QVariant::fromValue(todo);
+    }
+
     if (role == IsRichTextRole) {
         if (index.column() == SummaryColumn) {
             return QVariant(todo->summaryIsRich());
@@ -433,13 +434,11 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         return true;
     }
 
-    const Akonadi::Item item
-        = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto item = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
     const KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
 
     if (!item.isValid() || !todo) {
-        qCWarning(CALENDARVIEW_LOG)
-            << "TodoModel::setData() called, bug item is invalid or doesn't have payload";
+        qCWarning(CALENDARVIEW_LOG) << "TodoModel::setData() called, bug item is invalid or doesn't have payload";
         Q_ASSERT(false);
         return false;
     }
@@ -449,7 +448,7 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         if (role == Qt::CheckStateRole && index.column() == 0) {
             const bool checked = static_cast<Qt::CheckState>(value.toInt()) == Qt::Checked;
             if (checked) {
-                todo->setCompleted(QDateTime::currentDateTimeUtc());    // Because it calls Todo::recurTodo()
+                todo->setCompleted(QDateTime::currentDateTimeUtc()); // Because it calls Todo::recurTodo()
             } else {
                 todo->setCompleted(false);
             }
@@ -468,15 +467,13 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
             case PercentColumn:
                 todo->setPercentComplete(value.toInt());
                 break;
-            case StartDateColumn:
-            {
+            case StartDateColumn: {
                 QDateTime tmp = todo->dtStart();
                 tmp.setDate(value.toDate());
                 todo->setDtStart(tmp);
                 break;
             }
-            case DueDateColumn:
-            {
+            case DueDateColumn: {
                 QDateTime tmp = todo->dtDue();
                 tmp.setDate(value.toDate());
                 todo->setDtDue(tmp);
@@ -503,7 +500,7 @@ bool TodoModel::setData(const QModelIndex &index, const QVariant &value, int rol
         return true;
     } else {
         if (!(role == Qt::CheckStateRole && index.column() == 0)) {
-            //KOHelper::showSaveIncidenceErrorMsg( 0, todo ); //TODO pass parent
+            // KOHelper::showSaveIncidenceErrorMsg( 0, todo ); //TODO pass parent
             qCCritical(CALENDARVIEW_LOG) << "Unable to modify incidence";
         }
         return false;
@@ -537,77 +534,60 @@ void TodoModel::setSourceModel(QAbstractItemModel *model)
     beginResetModel();
 
     if (sourceModel()) {
-        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                   d, SLOT(onDataChanged(QModelIndex,QModelIndex)));
-        disconnect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                   d, SLOT(onHeaderDataChanged(Qt::Orientation,int,int)));
+        disconnect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), d.get(), SLOT(onDataChanged(QModelIndex, QModelIndex)));
+        disconnect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation, int, int)), d.get(), SLOT(onHeaderDataChanged(Qt::Orientation, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                   d, SLOT(onRowsInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)), d.get(), SLOT(onRowsInserted(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                   d, SLOT(onRowsRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)), d.get(), SLOT(onRowsRemoved(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-                   d, SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
+        disconnect(sourceModel(),
+                   SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)),
+                   d.get(),
+                   SLOT(onRowsMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                   d, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), d.get(), SLOT(onRowsAboutToBeInserted(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                   d, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
+        disconnect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), d.get(), SLOT(onRowsAboutToBeRemoved(QModelIndex, int, int)));
 
-        disconnect(sourceModel(), SIGNAL(modelAboutToBeReset()),
-                   d, SLOT(onModelAboutToBeReset()));
+        disconnect(sourceModel(), SIGNAL(modelAboutToBeReset()), d.get(), SLOT(onModelAboutToBeReset()));
 
-        disconnect(sourceModel(), SIGNAL(modelReset()),
-                   d, SLOT(onModelReset()));
+        disconnect(sourceModel(), SIGNAL(modelReset()), d.get(), SLOT(onModelReset()));
 
-        disconnect(sourceModel(), SIGNAL(layoutAboutToBeChanged()),
-                   d, SLOT(onLayoutAboutToBeChanged()));
+        disconnect(sourceModel(), SIGNAL(layoutAboutToBeChanged()), d.get(), SLOT(onLayoutAboutToBeChanged()));
 
-        disconnect(sourceModel(), SIGNAL(layoutChanged()),
-                   d, SLOT(onLayoutChanged()));
+        disconnect(sourceModel(), SIGNAL(layoutChanged()), d.get(), SLOT(onLayoutChanged()));
     }
 
     QAbstractProxyModel::setSourceModel(model);
 
     if (sourceModel()) {
-        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-                d, SLOT(onDataChanged(QModelIndex,QModelIndex)));
+        connect(sourceModel(), SIGNAL(dataChanged(QModelIndex, QModelIndex)), d.get(), SLOT(onDataChanged(QModelIndex, QModelIndex)));
 
-        connect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation,int,int)),
-                d, SLOT(onHeaderDataChanged(Qt::Orientation,int,int)));
+        connect(sourceModel(), SIGNAL(headerDataChanged(Qt::Orientation, int, int)), d.get(), SLOT(onHeaderDataChanged(Qt::Orientation, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex,int,int)),
-                d, SLOT(onRowsAboutToBeInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsAboutToBeInserted(QModelIndex, int, int)), d.get(), SLOT(onRowsAboutToBeInserted(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex,int,int)),
-                d, SLOT(onRowsInserted(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsInserted(QModelIndex, int, int)), d.get(), SLOT(onRowsInserted(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex,int,int)),
-                d, SLOT(onRowsAboutToBeRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsAboutToBeRemoved(QModelIndex, int, int)), d.get(), SLOT(onRowsAboutToBeRemoved(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex,int,int)),
-                d, SLOT(onRowsRemoved(QModelIndex,int,int)));
+        connect(sourceModel(), SIGNAL(rowsRemoved(QModelIndex, int, int)), d.get(), SLOT(onRowsRemoved(QModelIndex, int, int)));
 
-        connect(sourceModel(), SIGNAL(rowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)),
-                d, SLOT(onRowsAboutToBeMoved(QModelIndex,int,int,QModelIndex,int)));
+        connect(sourceModel(),
+                SIGNAL(rowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)),
+                d.get(),
+                SLOT(onRowsAboutToBeMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        connect(sourceModel(), SIGNAL(rowsMoved(QModelIndex,int,int,QModelIndex,int)),
-                d, SLOT(onRowsMoved(QModelIndex,int,int,QModelIndex,int)));
+        connect(sourceModel(), SIGNAL(rowsMoved(QModelIndex, int, int, QModelIndex, int)), d.get(), SLOT(onRowsMoved(QModelIndex, int, int, QModelIndex, int)));
 
-        connect(sourceModel(), SIGNAL(modelAboutToBeReset()),
-                d, SLOT(onModelAboutToBeReset()));
+        connect(sourceModel(), SIGNAL(modelAboutToBeReset()), d.get(), SLOT(onModelAboutToBeReset()));
 
-        connect(sourceModel(), SIGNAL(modelReset()),
-                d, SLOT(onModelReset()));
+        connect(sourceModel(), SIGNAL(modelReset()), d.get(), SLOT(onModelReset()));
 
-        connect(sourceModel(), SIGNAL(layoutAboutToBeChanged()),
-                d, SLOT(onLayoutAboutToBeChanged()));
+        connect(sourceModel(), SIGNAL(layoutAboutToBeChanged()), d.get(), SLOT(onLayoutAboutToBeChanged()));
 
-        connect(sourceModel(), SIGNAL(layoutChanged()),
-                d, SLOT(onLayoutChanged()));
+        connect(sourceModel(), SIGNAL(layoutChanged()), d.get(), SLOT(onLayoutChanged()));
     }
 
     endResetModel();
@@ -638,8 +618,10 @@ QVariant TodoModel::headerData(int column, Qt::Orientation orientation, int role
             return QVariant(i18n("Start Date"));
         case DueDateColumn:
             return QVariant(i18n("Due Date"));
+        case CompletedDateColumn:
+            return QVariant(i18nc("@title:column date completed", "Completed"));
         case CategoriesColumn:
-            return QVariant(i18n("Categories"));
+            return QVariant(i18n("Tags"));
         case DescriptionColumn:
             return QVariant(i18n("Description"));
         case CalendarColumn:
@@ -688,8 +670,7 @@ QMimeData *TodoModel::mimeData(const QModelIndexList &indexes) const
 {
     Akonadi::Item::List items;
     for (const QModelIndex &index : indexes) {
-        const Akonadi::Item item
-            = this->data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+        const auto item = this->data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
         if (item.isValid() && !items.contains(item)) {
             items.push_back(item);
         }
@@ -699,16 +680,15 @@ QMimeData *TodoModel::mimeData(const QModelIndexList &indexes) const
 
 bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int row, int column, const QModelIndex &parent)
 {
-    Q_UNUSED(row);
-    Q_UNUSED(column);
+    Q_UNUSED(row)
+    Q_UNUSED(column)
 
     if (action != Qt::MoveAction) {
-        qCWarning(CALENDARVIEW_LOG) << "No action other than MoveAction currently supported!"; //TODO
+        qCWarning(CALENDARVIEW_LOG) << "No action other than MoveAction currently supported!"; // TODO
         return false;
     }
 
-    if (d->m_calendar && d->m_changer
-        && (KCalUtils::ICalDrag::canDecode(data) || KCalUtils::VCalDrag::canDecode(data))) {
+    if (d->m_calendar && d->m_changer && (KCalUtils::ICalDrag::canDecode(data) || KCalUtils::VCalDrag::canDecode(data))) {
         KCalUtils::DndFactory dndFactory(d->m_calendar);
         KCalendarCore::Todo::Ptr t = dndFactory.createDropTodo(data);
         KCalendarCore::Event::Ptr e = dndFactory.createDropEvent(data);
@@ -720,8 +700,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
             KCalendarCore::Todo::Ptr todo = CalendarSupport::todo(item);
             KCalendarCore::Todo::Ptr destTodo;
             if (parent.isValid()) {
-                const Akonadi::Item parentItem
-                    = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+                const auto parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
                 if (parentItem.isValid()) {
                     destTodo = CalendarSupport::todo(parentItem);
                 }
@@ -729,11 +708,11 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
 
             KCalendarCore::Incidence::Ptr tmp = destTodo;
             while (tmp) {
-                if (tmp->uid() == todo->uid()) {   //correct, don't use instanceIdentifier() here
-                    KMessageBox::information(
-                        nullptr,
-                        i18n("Cannot move to-do to itself or a child of itself."),
-                        i18n("Drop To-do"), QStringLiteral("NoDropTodoOntoItself"));
+                if (tmp->uid() == todo->uid()) { // correct, don't use instanceIdentifier() here
+                    KMessageBox::information(nullptr,
+                                             i18n("Cannot move to-do to itself or a child of itself."),
+                                             i18n("Drop To-do"),
+                                             QStringLiteral("NoDropTodoOntoItself"));
                     return false;
                 }
                 const QString parentUid = tmp->relatedTo();
@@ -761,8 +740,7 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                 return false;
             }
 
-            const Akonadi::Item parentItem
-                = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+            const auto parentItem = this->data(parent, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
             KCalendarCore::Todo::Ptr destTodo = CalendarSupport::todo(parentItem);
 
             if (data->hasText()) {
@@ -774,11 +752,11 @@ bool TodoModel::dropMimeData(const QMimeData *data, Qt::DropAction action, int r
                     destTodo->addAttachment(KCalendarCore::Attachment(text));
                 } else {
                     QStringList emails = KEmailAddress::splitAddressList(text);
-                    for (QStringList::ConstIterator it = emails.constBegin();
-                         it != emails.constEnd(); ++it) {
-                        QString name, email, comment;
-                        if (KEmailAddress::splitAddress(*it, name, email, comment)
-                            == KEmailAddress::AddressOk) {
+                    for (QStringList::ConstIterator it = emails.constBegin(); it != emails.constEnd(); ++it) {
+                        QString name;
+                        QString email;
+                        QString comment;
+                        if (KEmailAddress::splitAddress(*it, name, email, comment) == KEmailAddress::AddressOk) {
                             destTodo->addAttendee(KCalendarCore::Attendee(name, email));
                         }
                     }
@@ -800,8 +778,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
 
     Qt::ItemFlags ret = QAbstractItemModel::flags(index);
 
-    const Akonadi::Item item
-        = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
+    const auto item = data(index, Akonadi::EntityTreeModel::ItemRole).value<Akonadi::Item>();
 
     if (!item.isValid()) {
         Q_ASSERT(mapToSource(index).isValid());
@@ -837,8 +814,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
         // whole rows should have checkboxes, so append the flag for the
         // first item of every row only. Also, only the first item of every
         // row should be used as a target for a drag and drop operation.
-        ret |= Qt::ItemIsUserCheckable
-               |Qt::ItemIsDropEnabled;
+        ret |= Qt::ItemIsUserCheckable | Qt::ItemIsDropEnabled;
     }
     return ret;
 }
@@ -846,7 +822,7 @@ Qt::ItemFlags TodoModel::flags(const QModelIndex &index) const
 QModelIndex TodoModel::mapFromSource(const QModelIndex &sourceIndex) const
 {
     if (!sourceModel() || !sourceIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     Q_ASSERT(sourceIndex.internalPointer());
@@ -857,20 +833,18 @@ QModelIndex TodoModel::mapFromSource(const QModelIndex &sourceIndex) const
 QModelIndex TodoModel::mapToSource(const QModelIndex &proxyIndex) const
 {
     if (!sourceModel() || !proxyIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
 
     if (proxyIndex.column() != 0) {
-        qCCritical(CALENDARVIEW_LOG)
-            << "Map to source called with column>0, but source model only has 1 column";
+        qCCritical(CALENDARVIEW_LOG) << "Map to source called with column>0, but source model only has 1 column";
         Q_ASSERT(false);
     }
 
     Q_ASSERT(proxyIndex.internalPointer());
 
     // we convert to column 0
-    const QModelIndex sourceIndex = SourceModelIndex(proxyIndex.row(), 0,
-                                                     proxyIndex.internalPointer(), sourceModel());
+    const QModelIndex sourceIndex = SourceModelIndex(proxyIndex.row(), 0, proxyIndex.internalPointer(), sourceModel());
 
     return sourceIndex;
 }
@@ -882,14 +856,10 @@ QModelIndex TodoModel::index(int row, int column, const QModelIndex &parent) con
     }
 
     Q_ASSERT(!parent.isValid() || parent.internalPointer());
-    QModelIndex parent_col0
-        = parent.isValid()
-          ? createIndex(parent.row(), 0, parent.internalPointer())
-          : QModelIndex();
+    QModelIndex parent_col0 = parent.isValid() ? createIndex(parent.row(), 0, parent.internalPointer()) : QModelIndex();
 
     // Lets preserve the original internalPointer
-    const QModelIndex index
-        = mapFromSource(sourceModel()->index(row, 0, mapToSource(parent_col0)));
+    const QModelIndex index = mapFromSource(sourceModel()->index(row, 0, mapToSource(parent_col0)));
 
     Q_ASSERT(!index.isValid() || index.internalPointer());
 
@@ -897,7 +867,7 @@ QModelIndex TodoModel::index(int row, int column, const QModelIndex &parent) con
         return createIndex(row, column, index.internalPointer());
     }
 
-    return QModelIndex();
+    return {};
 }
 
 QModelIndex TodoModel::parent(const QModelIndex &child) const
@@ -911,11 +881,11 @@ QModelIndex TodoModel::parent(const QModelIndex &child) const
     QModelIndex parentIndex = mapFromSource(sourceModel()->parent(mapToSource(child_col0)));
 
     Q_ASSERT(!parentIndex.isValid() || parentIndex.internalPointer());
-    if (parentIndex.isValid()) {   // preserve original column
+    if (parentIndex.isValid()) { // preserve original column
         return createIndex(parentIndex.row(), child.column(), parentIndex.internalPointer());
     }
 
-    return QModelIndex();
+    return {};
 }
 
 QModelIndex TodoModel::buddy(const QModelIndex &index) const
@@ -924,3 +894,19 @@ QModelIndex TodoModel::buddy(const QModelIndex &index) const
     // source model doesn't have the same number of columns.
     return index;
 }
+
+QHash<int, QByteArray> TodoModel::roleNames() const
+{
+    return {
+        {SummaryRole, QByteArrayLiteral("summary")},
+        {RecurRole, QByteArrayLiteral("recur")},
+        {PriorityRole, QByteArrayLiteral("priority")},
+        {PercentRole, QByteArrayLiteral("percent")},
+        {StartDateRole, QByteArrayLiteral("startDate")},
+        {DueDateRole, QByteArrayLiteral("dueDate")},
+        {CategoriesRole, QByteArrayLiteral("categories")},
+        {DescriptionRole, QByteArrayLiteral("description")},
+        {CalendarRole, QByteArrayLiteral("calendar")},
+        {Qt::CheckStateRole, QByteArrayLiteral("checked")},
+    };
+}
